% Auto-generated chapter 80 for bukhari
% Hadiths in this chapter: 106

\hadithdefcmd{bukhari}{6304}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لِكُلِّ نَبِيٍّ دَعْوَةٌ مُسْتَجَابَةٌ يَدْعُو بِهَا، وَأُرِيدُ أَنْ أَخْتَبِئَ دَعْوَتِي شَفَاعَةً لأُمَّتِي فِي الآخِرَةِ ‏"‏‏.‏\hadithno{6304}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "For every prophet there is one (special invocation (that will not be rejected) with which he appeals (to Allah), and I want to keep such an invocation for interceding for my followers in the Hereafter}}
\hadithdefcmd{bukhari}{6305}{وَقَالَ لِي خَلِيفَةُ قَالَ مُعْتَمِرٌ سَمِعْتُ أَبِي، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ نَبِيٍّ سَأَلَ سُؤْلاً ـ أَوْ قَالَ لِكُلِّ نَبِيٍّ دَعْوَةٌ قَدْ دَعَا بِهَا ـ فَاسْتُجِيبَ، فَجَعَلْتُ دَعْوَتِي شَفَاعَةً لأُمَّتِي يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{6305}\hadithtrans{Narrated Anas: that the Prophet (ﷺ) said, "For every prophet there is an invocation that surely will be responded by Allah," (or said), "For every prophet there was an invocation with which he appealed to Allah, and his invocation was accepted (in his lifetime), but I kept my (this special) invocation to intercede for my followers on the Day of Resurrection}}
\hadithdefcmd{bukhari}{6306}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا الْحُسَيْنُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ بُشَيْرِ بْنِ كَعْبٍ الْعَدَوِيِّ، قَالَ حَدَّثَنِي شَدَّادُ بْنُ أَوْسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ سَيِّدُ الاِسْتِغْفَارِ أَنْ تَقُولَ اللَّهُمَّ أَنْتَ رَبِّي، لاَ إِلَهَ إِلاَّ أَنْتَ، خَلَقْتَنِي وَأَنَا عَبْدُكَ، وَأَنَا عَلَى عَهْدِكَ وَوَعْدِكَ مَا اسْتَطَعْتُ، أَعُوذُ بِكَ مِنْ شَرِّ مَا صَنَعْتُ، أَبُوءُ لَكَ بِنِعْمَتِكَ عَلَىَّ وَأَبُوءُ لَكَ بِذَنْبِي، فَاغْفِرْ لِي، فَإِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ ‏"‏‏.‏ قَالَ ‏"‏ وَمَنْ قَالَهَا مِنَ النَّهَارِ مُوقِنًا بِهَا، فَمَاتَ مِنْ يَوْمِهِ قَبْلَ أَنْ يُمْسِيَ، فَهُوَ مِنْ أَهْلِ الْجَنَّةِ، وَمَنْ قَالَهَا مِنَ اللَّيْلِ وَهْوَ مُوقِنٌ بِهَا، فَمَاتَ قَبْلَ أَنْ يُصْبِحَ، فَهْوَ مِنْ أَهْلِ الْجَنَّةِ ‏"‏‏.‏\hadithno{6306}\hadithtrans{Narrated Shaddad bin Aus:The Prophet (ﷺ) said "The most superior way of asking for forgiveness from Allah is: 'Allahumma anta Rabbi la ilaha illa anta, Khalaqtani wa ana `Abduka, wa ana `ala `ahdika wa wa`dika mastata`tu, A`udhu bika min Sharri ma sana`tu, abu'u Laka bini`matika `alaiya, wa abu'u laka bidhanbi faghfir lee fa innahu la yaghfiru adhdhunuba illa anta." The Prophet (ﷺ) added. "If somebody recites it during the day with firm faith in it, and dies on the same day before the evening, he will be from the people of Paradise; and if somebody recites it at night with firm faith in it, and dies before the morning, he will be from the people of Paradise}}
\hadithdefcmd{bukhari}{6307}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ قَالَ أَبُو هُرَيْرَةَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَاللَّهِ إِنِّي لأَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ فِي الْيَوْمِ أَكْثَرَ مِنْ سَبْعِينَ مَرَّةً ‏"‏‏.‏\hadithno{6307}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying." By Allah! I ask for forgiveness from Allah and turn to Him in repentance more than seventy times a day}}
\hadithdefcmd{bukhari}{6308}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، حَدَّثَنَا عَبْدُ اللَّهِ، حَدِيثَيْنِ أَحَدُهُمَا عَنِ النَّبِيِّ صلى الله عليه وسلم وَالآخَرُ عَنْ نَفْسِهِ، قَالَ ‏"‏ إِنَّ الْمُؤْمِنَ يَرَى ذُنُوبَهُ كَأَنَّهُ قَاعِدٌ تَحْتَ جَبَلٍ يَخَافُ أَنْ يَقَعَ عَلَيْهِ، وَإِنَّ الْفَاجِرَ يَرَى ذُنُوبَهُ كَذُبَابٍ مَرَّ عَلَى أَنْفِهِ ‏"‏‏.‏ فَقَالَ بِهِ هَكَذَا قَالَ أَبُو شِهَابٍ بِيَدِهِ فَوْقَ أَنْفِهِ‏.‏ ثُمَّ قَالَ ‏"‏ لَلَّهُ أَفْرَحُ بِتَوْبَةِ عَبْدِهِ مِنْ رَجُلٍ نَزَلَ مَنْزِلاً، وَبِهِ مَهْلَكَةٌ، وَمَعَهُ رَاحِلَتُهُ عَلَيْهَا طَعَامُهُ وَشَرَابُهُ، فَوَضَعَ رَأْسَهُ فَنَامَ نَوْمَةً، فَاسْتَيْقَظَ وَقَدْ ذَهَبَتْ رَاحِلَتُهُ، حَتَّى اشْتَدَّ عَلَيْهِ الْحَرُّ وَالْعَطَشُ أَوْ مَا شَاءَ اللَّهُ، قَالَ أَرْجِعُ إِلَى مَكَانِي‏.‏ فَرَجَعَ فَنَامَ نَوْمَةً، ثُمَّ رَفَعَ رَأْسَهُ، فَإِذَا رَاحِلَتُهُ عِنْدَهُ ‏"‏‏.‏ تَابَعَهُ أَبُو عَوَانَةَ وَجَرِيرٌ عَنِ الأَعْمَشِ‏.‏ وَقَالَ أَبُو أُسَامَةَ حَدَّثَنَا الأَعْمَشُ حَدَّثَنَا عُمَارَةُ سَمِعْتُ الْحَارِثَ‏.‏ وَقَالَ شُعْبَةُ وَأَبُو مُسْلِمٍ عَنِ الأَعْمَشِ عَنْ إِبْرَاهِيمَ التَّيْمِيِّ عَنِ الْحَارِثِ بْنِ سُوَيْدٍ‏.‏ وَقَالَ أَبُو مُعَاوِيَةَ حَدَّثَنَا الأَعْمَشُ عَنْ عُمَارَةَ عَنِ الأَسْوَدِ عَنْ عَبْدِ اللَّهِ وَعَنْ إِبْرَاهِيمَ التَّيْمِيِّ عَنِ الْحَارِثِ بْنِ سُوَيْدٍ عَنْ عَبْدِ اللَّهِ‏.‏\hadithno{6308}\hadithtrans{Narrated Al-Harith bin Suwaid:`Abdullah bin Mas`ud related to us two narrations: One from the Prophet (ﷺ) and the other from himself, saying: A believer sees his sins as if he were sitting under a mountain which, he is afraid, may fall on him; whereas the wicked person considers his sins as flies passing over his nose and he just drives them away like this." Abu Shihab (the sub-narrator) moved his hand over his nose in illustration. (Ibn Mas`ud added): Allah's Messenger (ﷺ) said, "Allah is more pleased with the repentance of His slave than a man who encamps at a place where his life is jeopardized, but he has his riding beast carrying his food and water. He then rests his head and sleeps for a short while and wakes to find his riding beast gone. (He starts looking for it) and suffers from severe heat and thirst or what Allah wished (him to suffer from). He then says, 'I will go back to my place.' He returns and sleeps again, and then (getting up), he raises his head to find his riding beast standing beside him}}
\hadithdefcmd{bukhari}{6309}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنَا هُدْبَةُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُ أَفْرَحُ بِتَوْبَةِ عَبْدِهِ مِنْ أَحَدِكُمْ سَقَطَ عَلَى بَعِيرِهِ، وَقَدْ أَضَلَّهُ فِي أَرْضِ فَلاَةٍ ‏"‏‏.‏\hadithno{6309}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "Allah is more pleased with the repentance of His slave than anyone of you is pleased with finding his camel which he had lost in the desert}}
\hadithdefcmd{bukhari}{6310}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ إِحْدَى عَشْرَةَ رَكْعَةً، فَإِذَا طَلَعَ الْفَجْرُ صَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ، حَتَّى يَجِيءَ الْمُؤَذِّنُ فَيُؤْذِنَهُ‏.‏\hadithno{6310}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) used to pray eleven rak`at in the late part of the night, and when dawn appeared, he would offer two rak`at and then lie on his right side till the Muadhdhin came to inform him (that the morning prayer was due)}}
\hadithdefcmd{bukhari}{6311}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ مَنْصُورًا، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، قَالَ حَدَّثَنِي الْبَرَاءُ بْنُ عَازِبٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَتَيْتَ مَضْجَعَكَ فَتَوَضَّأْ وَضُوءَكَ لِلصَّلاَةِ، ثُمَّ اضْطَجِعْ عَلَى شِقِّكَ الأَيْمَنِ، وَقُلِ اللَّهُمَّ أَسْلَمْتُ وَجْهِي إِلَيْكَ، وَفَوَّضْتُ أَمْرِي إِلَيْكَ، وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ، رَغْبَةً وَرَهْبَةً إِلَيْكَ، لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ، آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ، وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ‏.‏ فَإِنْ مُتَّ مُتَّ عَلَى الْفِطْرَةِ، فَاجْعَلْهُنَّ آخِرَ مَا تَقُولُ ‏"‏‏.‏ فَقُلْتُ أَسْتَذْكِرُهُنَّ وَبِرَسُولِكَ الَّذِي أَرْسَلْتَ‏.‏ قَالَ ‏"‏ لاَ، وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏"‏‏.‏\hadithno{6311}\hadithtrans{Narrated Al-Bara bin `Azib:Allah's Messenger (ﷺ) said to me, "When you want to go to bed, perform ablution as you do for prayer, then lie down on your right side and say: 'Allahumma aslamtu wajhi ilaika, wa fawwadtu 'amri ilaika wa alja'tu dhahri ilaika, raghbatan wa rahbatan ilaika, la malja'a wa la manja minka illa ilaika. Amantu bikitabik al-ladhi anzalta wa binabiyyika al-ladhi arsalta'. If you should die then (after reciting this) you will die on the religion of Islam (i.e., as a Muslim); so let these words be the last you say (before going to bed)" While I was memorizing it, I said, "Wa birasulika al-ladhi arsalta (in Your Apostle whom You have sent).' The Prophet (ﷺ) said, "No, but say: Wa binabiyyika al-ladhi arsalta (in Your Prophet whom You have sent)}}
\hadithdefcmd{bukhari}{6312}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَوَى إِلَى فِرَاشِهِ قَالَ ‏"‏ بِاسْمِكَ أَمُوتُ وَأَحْيَا ‏"‏‏.‏ وَإِذَا قَامَ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا وَإِلَيْهِ النُّشُورُ ‏"‏‏.‏ تُنْشِرُهَا: تُخْرِجُهَا\hadithno{6312}\hadithtrans{Narrated Hudhaifa:When the Prophet (ﷺ) went to bed, he would say: "Bismika amutu wa ahya." and when he got up he would say:" Al-hamdu li l-lahil-ladhi ahyana ba'da ma amatana wa ilaihin-nushur}}
\hadithdefcmd{bukhari}{6313}{حَدَّثَنَا سَعِيدُ بْنُ الرَّبِيعِ، وَمُحَمَّدُ بْنُ عَرْعَرَةَ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، سَمِعَ الْبَرَاءَ بْنَ عَازِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ رَجُلاً‏.‏ وَحَدَّثَنَا آدَمُ حَدَّثَنَا شُعْبَةُ حَدَّثَنَا أَبُو إِسْحَاقَ الْهَمْدَانِيُّ عَنِ الْبَرَاءِ بْنِ عَازِبٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَوْصَى رَجُلاً فَقَالَ ‏ "‏ إِذَا أَرَدْتَ مَضْجَعَكَ فَقُلِ اللَّهُمَّ أَسْلَمْتُ نَفْسِي إِلَيْكَ، وَفَوَّضْتُ أَمْرِي إِلَيْكَ، وَوَجَّهْتُ وَجْهِي إِلَيْكَ، وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ، رَغْبَةً وَرَهْبَةً إِلَيْكَ، لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ، آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ، وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ‏.‏ فَإِنْ مُتَّ مُتَّ عَلَى الْفِطْرَةِ ‏"‏‏.‏\hadithno{6313}\hadithtrans{Narrated Al-Bara bin `Azib:That the Prophet (ﷺ) advised a man, saying, "If you intend to lie down (i.e. go to bed), say, 'Allahumma aslamtu nafsi ilaika wa fauwadtu `Amri ilaika, wa wajjahtu wajhi ilaika wa alja'tu zahri ilaika, reghbatan wa rahbatan ilaika. La malja'a wa la manja minka illa ilaika. Amantu bikitabikal-ladhi anzalta; wa nabiyyikalladhi arsalta.' And if you should die then (after reciting this before going to bed) you will die on the religion of Islam}}
\hadithdefcmd{bukhari}{6314}{حَدَّثَنِي مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ ـ رضى الله عنه قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَخَذَ مَضْجَعَهُ مِنَ اللَّيْلِ وَضَعَ يَدَهُ تَحْتَ خَدِّهِ ثُمَّ يَقُولُ ‏"‏ اللَّهُمَّ بِاسْمِكَ أَمُوتُ وَأَحْيَا ‏"‏‏.‏ وَإِذَا اسْتَيْقَظَ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا وَإِلَيْهِ النُّشُورُ ‏"‏‏.‏\hadithno{6314}\hadithtrans{Narrated Hudhaifa:When the Prophet (ﷺ) went to bed at night, he would put his hand under his cheek and then say, "Allahumma bismika amutu wa ahya," and when he got up, he would say, "Al-Hamdu lil-lahi al-ladhi ahyana ba'da ma amatana, wa ilaihi an-nushur}}
\hadithdefcmd{bukhari}{6315}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الْعَلاَءُ بْنُ الْمُسَيَّبِ، قَالَ حَدَّثَنِي أَبِي، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَوَى إِلَى فِرَاشِهِ نَامَ عَلَى شِقِّهِ الأَيْمَنِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ أَسْلَمْتُ نَفْسِي إِلَيْكَ، وَوَجَّهْتُ وَجْهِي إِلَيْكَ، وَفَوَّضْتُ أَمْرِي إِلَيْكَ، وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ، رَغْبَةً وَرَهْبَةً إِلَيْكَ، لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ، آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ، وَنَبِيِّكَ الَّذِي أَرْسَلْتَ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قَالَهُنَّ ثُمَّ مَاتَ تَحْتَ لَيْلَتِهِ مَاتَ عَلَى الْفِطْرَةِ ‏"‏‏.‏ ‏\{‏اسْتَرْهَبُوهُمْ‏\}‏ مِنَ الرَّهْبَةِ، مَلَكُوتٌ مُلْكٌ مَثَلُ رَهَبُوتٌ خَيْرٌ مِنْ رَحَمُوتٍ، تَقُولُ تَرْهَبُ خَيْرٌ مِنْ أَنْ تَرْحَمَ‏.‏\hadithno{6315}\hadithtrans{Narrated Al-Bara' bin `Azib:When Allah's Messenger (ﷺ) went to bed, he used to sleep on his right side and then say, "All-ahumma aslamtu nafsi ilaika, wa wajjahtu wajhi ilaika, wa fauwadtu `Amri ilaika, wa alja'tu zahri ilaika, raghbatan wa rahbatan ilaika. La Malja'a wa la manja minka illa ilaika. Amantu bikitabika al-ladhi anzalta wa nabiyyika al-ladhi arsalta! Allah's Messenger (ﷺ) said, "Whoever recites these words (before going to bed) and dies the same night, he will die on the Islamic religion (as a Muslim)}}
\hadithdefcmd{bukhari}{6316}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بِتُّ عِنْدَ مَيْمُونَةَ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَأَتَى حَاجَتَهُ، غَسَلَ وَجْهَهُ وَيَدَيْهِ، ثُمَّ نَامَ، ثُمَّ قَامَ فَأَتَى الْقِرْبَةَ فَأَطْلَقَ شِنَاقَهَا، ثُمَّ تَوَضَّأَ وُضُوءًا بَيْنَ وُضُوءَيْنِ لَمْ يُكْثِرْ، وَقَدْ أَبْلَغَ، فَصَلَّى، فَقُمْتُ فَتَمَطَّيْتُ كَرَاهِيَةَ أَنْ يَرَى أَنِّي كُنْتُ أَتَّقِيهِ، فَتَوَضَّأْتُ، فَقَامَ يُصَلِّي، فَقُمْتُ عَنْ يَسَارِهِ، فَأَخَذَ بِأُذُنِي فَأَدَارَنِي عَنْ يَمِينِهِ، فَتَتَامَّتْ صَلاَتُهُ ثَلاَثَ عَشْرَةَ رَكْعَةً ثُمَّ اضْطَجَعَ فَنَامَ حَتَّى نَفَخَ ـ وَكَانَ إِذَا نَامَ نَفَخَ ـ فَآذَنَهُ بِلاَلٌ بِالصَّلاَةِ، فَصَلَّى وَلَمْ يَتَوَضَّأْ، وَكَانَ يَقُولُ فِي دُعَائِهِ ‏ "‏ اللَّهُمَّ اجْعَلْ فِي قَلْبِي نُورًا، وَفِي بَصَرِي نُورًا، وَفِي سَمْعِي نُورًا، وَعَنْ يَمِينِي نُورًا، وَعَنْ يَسَارِي نُورًا، وَفَوْقِي نُورًا، وَتَحْتِي نُورًا، وَأَمَامِي نُورًا، وَخَلْفِي نُورًا، وَاجْعَلْ لِي نُورًا ‏"‏‏.‏ قَالَ كُرَيْبٌ وَسَبْعٌ فِي التَّابُوتِ‏.‏ فَلَقِيتُ رَجُلاً مِنْ وَلَدِ الْعَبَّاسِ فَحَدَّثَنِي بِهِنَّ، فَذَكَرَ عَصَبِي وَلَحْمِي وَدَمِي وَشَعَرِي وَبَشَرِي، وَذَكَرَ خَصْلَتَيْنِ‏.‏\hadithno{6316}\hadithtrans{Narrated Ibn `Abbas:One night I slept at the house of Maimuna. The Prophet (ﷺ) woke up, answered the call of nature, washed his face and hands, and then slept. He got up (late at night), went to a water skin, opened the mouth thereof and performed ablution not using much water, yet he washed all the parts properly and then offered the prayer. I got up and straightened my back in order that the Prophet (ﷺ) might not feel that I was watching him, and then I performed the ablution, and when he got up to offer the prayer, I stood on his left. He caught hold of my ear and brought me over to his right side. He offered thirteen rak`at in all and then lay down and slept till he started blowing out his breath as he used to do when he slept. In the meantime Bilal informed the Prophet (ﷺ) of the approaching time for the (Fajr) prayer, and the Prophet offered the Fajr (Morning) prayer without performing new ablution. He used to say in his invocation, Allahumma ij`al fi qalbi nuran wa fi basari nuran, wa fi sam`i nuran, wa`an yamini nuran, wa`an yasari nuran, wa fawqi nuran, wa tahti nuran, wa amami nuran, wa khalfi nuran, waj`al li nuran." Kuraib (a sub narrator) said, "I have forgotten seven other words, (which the Prophet (ﷺ) mentioned in this invocation). I met a man from the offspring of Al-`Abbas and he narrated those seven things to me, mentioning, '(Let there be light in) my nerves, my flesh, my blood, my hair and my body,' and he also mentioned two other things}}
\hadithdefcmd{bukhari}{6317}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، سَمِعْتُ سُلَيْمَانَ بْنَ أَبِي مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَامَ مِنَ اللَّيْلِ يَتَهَجَّدُ قَالَ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ، أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ، وَلَكَ الْحَمْدُ أَنْتَ قَيِّمُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ، وَلَكَ الْحَمْدُ، أَنْتَ الْحَقُّ وَوَعْدُكَ حَقٌّ، وَقَوْلُكَ حَقٌّ، وَلِقَاؤُكَ حَقٌّ، وَالْجَنَّةُ حَقٌّ، وَالنَّارُ حَقٌّ، وَالسَّاعَةُ حَقٌّ، وَالنَّبِيُّونَ حَقٌّ، وَمُحَمَّدٌ حَقٌّ، اللَّهُمَّ لَكَ أَسْلَمْتُ وَعَلَيْكَ تَوَكَّلْتُ وَبِكَ آمَنْتُ، وَإِلَيْكَ أَنَبْتُ، وَبِكَ خَاصَمْتُ، وَإِلَيْكَ حَاكَمْتُ، فَاغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ، وَمَا أَسْرَرْتُ، وَمَا أَعْلَنْتُ، أَنْتَ الْمُقَدِّمُ وَأَنْتَ الْمُؤَخِّرُ لاَ إِلَهَ إِلاَّ أَنْتَ ـ أَوْ ـ لاَ إِلَهَ غَيْرُكَ ‏"‏‏.‏\hadithno{6317}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) got up at night to offer the night prayer, he used to say: "Allahumma laka l-hamdu; Anta nuras-samawati wal ardi wa man fihinna. wa laka l-hamdu; Anta qaiyim as-samawati wal ardi wa man flhinna. Wa lakaI-hamdu; Anta-l-,haqqun, wa wa'daka haqqun, wa qauluka haqqun, wa liqauka haqqun, wal-jannatu haqqun, wannaru haqqun, was-sa atu haqqun, wan-nabiyyuna huqqun, Mahammadun haqqun, Allahumma laka aslamtu, wa Alaika tawakkaltu, wa bika amantu, wa ilaika anabtu, wa bika Khasamtu, wa ilaika hakamtu, faghfirli ma qaddamtu wa ma akh-khartu, wa ma asrartu, wa ma a'lantu. Anta al-muqaddimu, wa anta al-mu-'akhkhiru. La ilaha il-la anta (or La ilaha ghairuka)}}
\hadithdefcmd{bukhari}{6318}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، أَنَّ فَاطِمَةَ ـ عَلَيْهِمَا السَّلاَمُ ـ شَكَتْ مَا تَلْقَى فِي يَدِهَا مِنَ الرَّحَى، فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم تَسْأَلُهُ خَادِمًا، فَلَمْ تَجِدْهُ، فَذَكَرَتْ ذَلِكَ لِعَائِشَةَ، فَلَمَّا جَاءَ أَخْبَرَتْهُ‏.‏ قَالَ فَجَاءَنَا وَقَدْ أَخَذْنَا مَضَاجِعَنَا، فَذَهَبْتُ أَقُومُ فَقَالَ ‏"‏ مَكَانَكِ ‏"‏‏.‏ فَجَلَسَ بَيْنَنَا حَتَّى وَجَدْتُ بَرْدَ قَدَمَيْهِ عَلَى صَدْرِي فَقَالَ ‏"‏ أَلاَ أَدُلُّكُمَا عَلَى مَا هُوَ خَيْرٌ لَكُمَا مِنْ خَادِمٍ، إِذَا أَوَيْتُمَا إِلَى فِرَاشِكُمَا، أَوْ أَخَذْتُمَا مَضَاجِعَكُمَا، فَكَبِّرَا ثَلاَثًا وَثَلاَثِينَ، وَسَبِّحَا ثَلاَثًا وَثَلاَثِينَ، وَاحْمَدَا ثَلاَثًا وَثَلاَثِينَ، فَهَذَا خَيْرٌ لَكُمَا مِنْ خَادِمٍ ‏"‏‏.‏ وَعَنْ شُعْبَةَ عَنْ خَالِدٍ عَنِ ابْنِ سِيرِينَ قَالَ التَّسْبِيحُ أَرْبَعٌ وَثَلاَثُونَ‏.‏\hadithno{6318}\hadithtrans{Narrated `Ali:Fatima complained about the blisters on her hand because of using a mill-stone. She went to ask the Prophet for servant, but she did not find him (at home) and had to inform `Aisha of her need. When he came, `Aisha informed him about it. `Ali added: The Prophet (ﷺ) came to us when we had gone to our beds. When I was going to get up, he said, "'Stay in your places," and sat between us, till I felt the coolness of the feet on my chest. The Prophet (ﷺ) then said, "Shall I not tell you of a thing which is better for you than a servant? When you (both) go to your beds, say 'Allahu Akbar' thirty-three times, and 'Subhan Allah' thirty-three times, 'Al hamdu 'illah' thirty-three times, for that is better for you than a servant." Ibn Seereen said, "Subhan Allah' (is to be said for) thirty-four times}}
\hadithdefcmd{bukhari}{6319}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَخَذَ مَضْجَعَهُ نَفَثَ فِي يَدَيْهِ، وَقَرَأَ بِالْمُعَوِّذَاتِ، وَمَسَحَ بِهِمَا جَسَدَهُ‏.‏\hadithno{6319}\hadithtrans{Narrated `Aisha:Whenever Allah's Messenger (ﷺ) went to bed, he used to blow on his hands while reciting the Mu'auwidhat ( i.e. Suratal-Falaq 113 and Surat-an-Nas 114) and then pass his hands over his body}}
\hadithdefcmd{bukhari}{6320}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَوَى أَحَدُكُمْ إِلَى فِرَاشِهِ فَلْيَنْفُضْ فِرَاشَهُ بِدَاخِلَةِ إِزَارِهِ، فَإِنَّهُ لاَ يَدْرِي مَا خَلَفَهُ عَلَيْهِ، ثُمَّ يَقُولُ بِاسْمِكَ رَبِّ وَضَعْتُ جَنْبِي، وَبِكَ أَرْفَعُهُ، إِنْ أَمْسَكْتَ نَفْسِي فَارْحَمْهَا، وَإِنْ أَرْسَلْتَهَا فَاحْفَظْهَا بِمَا تَحْفَظُ بِهِ عِبَادَكَ الصَّالِحِينَ ‏"‏‏.‏ تَابَعَهُ أَبُو ضَمْرَةَ وَإِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ عَنْ عُبَيْدِ اللَّهِ‏.‏ وَقَالَ يَحْيَى وَبِشْرٌ عَنْ عُبَيْدِ اللَّهِ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَرَوَاهُ مَالِكٌ وَابْنُ عَجْلاَنَ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6320}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When anyone of you go to bed, he should shake out his bed with the inside of his waist sheet, for he does not know what has come on to it after him, and then he should say: 'Bismika Rabbi Wada`tu Janbi wa bika arfa'uhu, In amsakta nafsi farhamha wa in arsaltaha fahfazha bima tahfazu bihi ibadakas-salihin}}
\hadithdefcmd{bukhari}{6321}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَتَنَزَّلُ رَبُّنَا تَبَارَكَ وَتَعَالَى كُلَّ لَيْلَةٍ إِلَى السَّمَاءِ الدُّنْيَا حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ يَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ، مَنْ يَسْأَلُنِي فَأُعْطِيَهُ، وَمَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ?"‏‏‏\hadithno{6321}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When it is the last third of the night, our Lord, the Blessed, the Superior, descends every night to the heaven of the world and says, 'Is there anyone who invokes Me (demand anything from Me), that I may respond to his invocation; Is there anyone who asks Me for something that I may give (it to) him; Is there anyone who asks My forgiveness that I may forgive him?}}
\hadithdefcmd{bukhari}{6322}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْخُبُثِ وَالْخَبَائِثِ ‏"‏‏.‏\hadithno{6322}\hadithtrans{Narrated Anas bin Malik:Whenever the Prophet (ﷺ) went to the lavatory, he used to say: "Allahumma inni a`udhu bika min al-khubuthi wal khaba'ith}}
\hadithdefcmd{bukhari}{6323}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حُسَيْنٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ بُشَيْرِ بْنِ كَعْبٍ، عَنْ شَدَّادِ بْنِ أَوْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ سَيِّدُ الاِسْتِغْفَارِ اللَّهُمَّ أَنْتَ رَبِّي لاَ إِلَهَ إِلاَّ أَنْتَ، خَلَقْتَنِي وَأَنَا عَبْدُكَ، وَأَنَا عَلَى عَهْدِكَ وَوَعْدِكَ مَا اسْتَطَعْتُ، أَبُوءُ لَكَ بِنِعْمَتِكَ، وَأَبُوءُ لَكَ بِذَنْبِي، فَاغْفِرْ لِي، فَإِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ، أَعُوذُ بِكَ مِنْ شَرِّ مَا صَنَعْتُ‏.‏ إِذَا قَالَ حِينَ يُمْسِي فَمَاتَ دَخَلَ الْجَنَّةَ ـ أَوْ كَانَ مِنْ أَهْلِ الْجَنَّةِ ـ وَإِذَا قَالَ حِينَ يُصْبِحُ فَمَاتَ مِنْ يَوْمِهِ ‏"‏‏.‏ مِثْلَهُ‏.‏\hadithno{6323}\hadithtrans{Narrated Shaddad bin 'Aus:The Prophet (ﷺ) said, "The most superior way of asking for forgiveness from Allah is: 'Allahumma anta Rabbi la ilaha illa anta. Khalaqtani wa ana `Abduka, wa ana 'ala 'ahdika wa Wa'dika mastata'tu abu'u Laka bi ni 'matika wa abu'u Laka bidhanbi; faghfirli fa'innahu la yaghfiru-dh-dhunuba ill a ant a. A'uidhu bika min sharri ma sana'tu.' If somebody recites this invocation during the night, and if he should die then, he will go to Paradise (or he will be from the people of Paradise). And if he recites it in the morning, and if he should die on the same day, he will have the same fate}}
\hadithdefcmd{bukhari}{6324}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَنَامَ قَالَ ‏"‏ بِاسْمِكَ اللَّهُمَّ أَمُوتُ وَأَحْيَا ‏"‏‏.‏ وَإِذَا اسْتَيْقَظَ مِنْ مَنَامِهِ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا، وَإِلَيْهِ النُّشُورُ ‏"‏‏.‏\hadithno{6324}\hadithtrans{Narrated Hudhaifa:Whenever the Prophet (ﷺ) intended to go to bed, he would recite: "Bismika Allahumma amutu wa ahya (With Your name, O Allah, I die and I live)." And when he woke up from his sleep, he would say: "Al-hamdu lil-lahil-ladhi ahyana ba'da ma amatana; wa ilaihi an-nushur (All the Praises are for Allah Who has made us alive after He made us die (sleep) and unto Him is the Resurrection}}
\hadithdefcmd{bukhari}{6325}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَخَذَ مَضْجَعَهُ مِنَ اللَّيْلِ قَالَ ‏"‏ اللَّهُمَّ بِاسْمِكَ أَمُوتُ وَأَحْيَا ‏"‏‏.‏ فَإِذَا اسْتَيْقَظَ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا وَإِلَيْهِ النُّشُورُ ‏"‏‏.‏\hadithno{6325}\hadithtrans{Narrated Abu Dhar:Whenever the Prophet (ﷺ) lay on his bed, he used to say: "Allahumma bismika amutu wa ahya," and when he woke up he would say: "Al-hamdu lil-lahilladhi ahyana ba'da ma an atana, wa ilaihi an-nushur}}
\hadithdefcmd{bukhari}{6326}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا اللَّيْثُ، قَالَ حَدَّثَنِي يَزِيدُ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ ـ رضى الله عنه ـ أَنَّهُ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم عَلِّمْنِي دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي‏.‏ قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي ظَلَمْتُ نَفْسِي ظُلْمًا كَثِيرًا، وَلاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ، فَاغْفِرْ لِي مَغْفِرَةً مِنْ عِنْدِكَ، وَارْحَمْنِي، إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏‏.‏ وَقَالَ عَمْرٌو عَنْ يَزِيدَ، عَنْ أَبِي الْخَيْرِ، إِنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو، قَالَ أَبُو بَكْرٍ ـ رضى الله عنه ـ لِلنَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6326}\hadithtrans{Narrated `Abdullah bin `Amr:Abu Bakr As-Siddiq said to the Prophet, "Teach me an invocation with which I may invoke (Allah) in my prayer." The Prophet (ﷺ) said, "Say: Allahumma inni zalamtu nafsi zulman kathiran wala yaghfirudhdhunuba illa anta, Faghfirli maghfiratan min indika war-hamni, innaka antalGhafur-Rahim}}
\hadithdefcmd{bukhari}{6327}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا مَالِكُ بْنُ سُعَيْرٍ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏ أُنْزِلَتْ فِي الدُّعَاءِ‏.‏\hadithno{6327}\hadithtrans{Narrated `Aisha:The Verse: 'Neither say your prayer aloud, nor say it in a low tone.' (17.110) was revealed as regards invocation}}
\hadithdefcmd{bukhari}{6328}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كُنَّا نَقُولُ فِي الصَّلاَةِ السَّلاَمُ عَلَى اللَّهِ، السَّلاَمُ عَلَى فُلاَنٍ‏.‏ فَقَالَ لَنَا النَّبِيُّ صلى الله عليه وسلم ذَاتَ يَوْمٍ ‏ "‏ إِنَّ اللَّهَ هُوَ السَّلاَمُ، فَإِذَا قَعَدَ أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَقُلِ التَّحِيَّاتُ لِلَّهِ إِلَى قَوْلِهِ الصَّالِحِينَ‏.‏ فَإِذَا قَالَهَا أَصَابَ كُلَّ عَبْدٍ لِلَّهِ فِي السَّمَاءِ وَالأَرْضِ صَالِحٍ، أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ‏.‏ ثُمَّ يَتَخَيَّرُ مِنَ الثَّنَاءِ مَا شَاءَ ‏"‏‏.‏\hadithno{6328}\hadithtrans{Narrated `Abdullah:We used to say in the prayer: 'AsSalam be on Allah, As-Salam be on so-and-so.' So one day the Prophet said to us, "Allah Himself is As-Salam; when anyone of you sits during his prayer, he should say: 'at-tah, iyyatu-li l-lahi,' up to 'As-Salihin,' (All the compliments are for Allah ...righteous people) for when he recites this, then he says his Salam to all the righteous people present in the heavens and on the earth. Then he should say, 'I testify that none has the right to be worshipped except Allah, and that Muhammad is His slave and His Apostle,' and then he can select whatever he likes to celebrate (Allah's) Praises}}
\hadithdefcmd{bukhari}{6329}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا يَزِيدُ، أَخْبَرَنَا وَرْقَاءُ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ،‏.‏ قَالُوا يَا رَسُولَ اللَّهِ ذَهَبَ أَهْلُ الدُّثُورِ بِالدَّرَجَاتِ وَالنَّعِيمِ الْمُقِيمِ‏.‏ قَالَ ‏"‏ كَيْفَ ذَاكَ ‏"‏‏.‏ قَالَ صَلَّوْا كَمَا صَلَّيْنَا، وَجَاهَدُوا كَمَا جَاهَدْنَا، وَأَنْفَقُوا مِنْ فُضُولِ أَمْوَالِهِمْ، وَلَيْسَتْ لَنَا أَمْوَالٌ‏.‏ قَالَ ‏"‏ أَفَلاَ أُخْبِرُكُمْ بِأَمْرٍ تُدْرِكُونَ مَنْ كَانَ قَبْلَكُمْ، وَتَسْبِقُونَ مَنْ جَاءَ بَعْدَكُمْ، وَلاَ يَأْتِي أَحَدٌ بِمِثْلِ مَا جِئْتُمْ، إِلاَّ مَنْ جَاءَ بِمِثْلِهِ، تُسَبِّحُونَ فِي دُبُرِ كُلِّ صَلاَةٍ عَشْرًا، وَتَحْمَدُونَ عَشْرًا، وَتُكَبِّرُونَ عَشْرًا ‏"‏‏.‏ تَابَعَهُ عُبَيْدُ اللَّهِ بْنُ عُمَرَ عَنْ سُمَىٍّ وَرَوَاهُ ابْنُ عَجْلاَنَ عَنْ سُمَىٍّ وَرَجَاءِ بْنِ حَيْوَةَ‏.‏ وَرَوَاهُ جَرِيرٌ عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ عَنْ أَبِي صَالِحٍ عَنْ أَبِي الدَّرْدَاءِ‏.‏ وَرَوَاهُ سُهَيْلٌ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6329}\hadithtrans{Narrated Abu Huraira:The people said, "O Allah's Messenger (ﷺ)! The rich people have got the highest degrees of prestige and the permanent pleasures (in this life and the life to come in the Hereafter)." He said, "How is that?" They said, "The rich pray as we pray, and strive in Allah's Cause as we do, and spend from their surplus wealth in charity, while we have no wealth (to spend likewise)." He said, "Shall I not tell you a thing, by doing which, you will catch up with those who are ahead of you and supersede those who will come after you; and nobody will be able to do such a good deed as you do except the one who does the same (deed as you do). That deed is to recite 'Subhan Allah ten times, and 'Al-Hamduli l-lah ten times, and 'AllahuAkbar' ten times after every prayer}}
\hadithdefcmd{bukhari}{6330}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ وَرَّادٍ، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ قَالَ كَتَبَ الْمُغِيرَةُ إِلَى مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ فِي دُبُرِ كُلِّ صَلاَةٍ إِذَا سَلَّمَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ، وَلَهُ الْحَمْدُ، وَهْوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ، اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ، وَلاَ مُعْطِيَ لِمَا مَنَعْتَ، وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏‏.‏ وَقَالَ شُعْبَةُ عَنْ مَنْصُورٍ قَالَ سَمِعْتُ الْمُسَيَّبَ‏.‏\hadithno{6330}\hadithtrans{Narrated Warrad:(the freed slave of Al-Mughira bin Shu`ba) Al-Mughira wrote to Muawiya bin Abu Sufyan that Allah's Messenger (ﷺ) used to say at the end of every prayer after the Taslim, "La ilaha illa-l-lahu wahdahu la sharika lahu; lahu-l-mulk wa lahu-l-hamd, wahuwa 'ala kulli shai'n qadir. Allahumma la mani'a Lima a taita, wa la mu'ta Lima mana'ta, wa la yanfa'u dhal-jaddu minkal-jadd}}
\hadithdefcmd{bukhari}{6331}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، مَوْلَى سَلَمَةَ حَدَّثَنَا سَلَمَةُ بْنُ الأَكْوَعِ، قَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم إِلَى خَيْبَرَ، قَالَ رَجُلٌ مِنَ الْقَوْمِ أَيَا عَامِرُ لَوْ أَسْمَعْتَنَا مِنْ هُنَيْهَاتِكَ‏.‏ فَنَزَلَ يَحْدُو بِهِمْ يُذَكِّرُ‏.‏ تَاللَّهِ لَوْلاَ اللَّهُ مَا اهْتَدَيْنَا‏.‏ وَذَكَرَ شِعْرًا غَيْرَ هَذَا، وَلَكِنِّي لَمْ أَحْفَظْهُ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هَذَا السَّائِقُ ‏"‏‏.‏ قَالُوا عَامِرُ بْنُ الأَكْوَعِ‏.‏ قَالَ ‏"‏ يَرْحَمُهُ اللَّهُ ‏"‏‏.‏ وَقَالَ رَجُلٌ مِنَ الْقَوْمِ يَا رَسُولَ اللَّهِ لَوْلاَ مَتَّعْتَنَا بِهِ، فَلَمَّا صَافَّ الْقَوْمَ قَاتَلُوهُمْ، فَأُصِيبَ عَامِرٌ بِقَائِمَةِ سَيْفِ نَفْسِهِ فَمَاتَ، فَلَمَّا أَمْسَوْا أَوْقَدُوا نَارًا كَثِيرَةً فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا هَذِهِ النَّارُ عَلَى أَىِّ شَىْءٍ تُوقِدُونَ ‏"‏‏.‏ قَالُوا عَلَى حُمُرٍ إِنْسِيَّةٍ‏.‏ فَقَالَ ‏"‏ أَهْرِيقُوا مَا فِيهَا، وَكَسِّرُوهَا ‏"‏‏.‏ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَلاَ نُهَرِيقُ مَا فِيهَا وَنَغْسِلُهَا قَالَ ‏"‏ أَوْ ذَاكَ ‏"‏‏.‏\hadithno{6331}\hadithtrans{Narrated Salama bin Al-Akwa`:We went out with the Prophet (ﷺ) to Khaibar. A man among the people said, "O 'Amir! Will you please recite to us some of your poetic verses?" So 'Amir got down and started chanting among them, saying, "By Allah! Had it not been for Allah, we would not have been guided." 'Amir also said other poetic verses which I do not remember. Allah's Messenger (ﷺ) said, "Who is this (camel) driver?" The people said, "He is 'Amir bin Al-Akwa`," He said, "May Allah bestow His Mercy on him." A man from the People said, "O Allah's Messenger (ﷺ)! Would that you let us enjoy his company longer." When the people (Muslims) lined up, the battle started, and 'Amir was struck with his own sword (by chance) by himself and died. In the evening, the people made a large number of fires (for cooking meals). Allah's Apostle said, "What is this fire? What are you making the fire for?" They said, "For cooking the meat of donkeys." He said, "Throw away what is in the pots and break the pots!" A man said, "O Allah's Prophet! May we throw away what is in them and wash them?" He said, "Never mind, you may do so." (See Hadith No. 509, Vol)}}
\hadithdefcmd{bukhari}{6332}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، سَمِعْتُ ابْنَ أَبِي أَوْفَى ـ رضى الله عنهما كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَتَاهُ رَجُلٌ بِصَدَقَةٍ قَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ فُلاَنٍ ‏"‏‏.‏ فَأَتَاهُ أَبِي فَقَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ أَبِي أَوْفَى ‏"‏‏.‏\hadithno{6332}\hadithtrans{Narrated Ibn Abi `Aufa:Whenever a man brought his alms to the Prophet, the Prophet (ﷺ) would say, "O Allah! Bestow Your Blessing upon the family of so-and-so." When my father came to him (with his alms), he said, "O Allah! Bestow Your Blessings upon the family of Abi `Aufa}}
\hadithdefcmd{bukhari}{6333}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ جَرِيرًا، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ تُرِيحُنِي مِنْ ذِي الْخَلَصَةِ ‏"‏‏.‏ وَهْوَ نُصُبٌ كَانُوا يَعْبُدُونَهُ يُسَمَّى الْكَعْبَةَ الْيَمَانِيَةَ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ لاَ أَثْبُتُ عَلَى الْخَيْلِ، فَصَكَّ فِي صَدْرِي فَقَالَ ‏"‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏‏.‏ قَالَ فَخَرَجْتُ فِي خَمْسِينَ مِنْ أَحْمَسَ مِنْ قَوْمِي ـ وَرُبَّمَا قَالَ سُفْيَانُ فَانْطَلَقْتُ فِي عُصْبَةٍ مِنْ قَوْمِي ـ فَأَتَيْتُهَا فَأَحْرَقْتُهَا، ثُمَّ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ، وَاللَّهِ مَا أَتَيْتُكَ حَتَّى تَرَكْتُهَا مِثْلَ الْجَمَلِ الأَجْرَبِ‏.‏ فَدَعَا لأَحْمَسَ وَخَيْلِهَا‏.‏\hadithno{6333}\hadithtrans{Narrated Jarir:Allah's Messenger (ﷺ) said to me. "Will you relieve me from Dhi-al-Khalasa? " Dhi-al-Khalasa was an idol which the people used to worship and it was called Al-Ka`ba al Yamaniyya. I said, "O Allah's Messenger (ﷺ) I am a man who can't sit firm on horses." So he stroked my chest (with his hand) and said, "O Allah! Make him firm and make him a guiding and well-guided man." So I went out with fifty (men) from my tribe of Ahrnas. (The sub-narrator, Sufyan, quoting Jarir, perhaps said, "I went out with a group of men from my nation.") and came to Dhi-al-Khalasa and burnt it, and then came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! I have not come to you till I left it like a camel with a skin disease." The Prophet then invoked good upon Ahmas and their cavalry (fighters)}}
\hadithdefcmd{bukhari}{6334}{حَدَّثَنَا سَعِيدُ بْنُ الرَّبِيعِ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، قَالَ قَالَتْ أُمُّ سُلَيْمٍ لِلنَّبِيِّ صلى الله عليه وسلم أَنَسٌ خَادِمُكَ‏.‏ قَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ، وَبَارِكْ لَهُ فِيمَا أَعْطَيْتَهُ ‏"‏‏.‏\hadithno{6334}\hadithtrans{Narrated Anas:Um Sulaim said to the Prophet (ﷺ) "Anas is your servant." The Prophet (ﷺ) said, "O Allah! increase his wealth and offspring, and bless (for him) what ever you give him}}
\hadithdefcmd{bukhari}{6335}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً يَقْرَأُ فِي الْمَسْجِدِ فَقَالَ ‏ "‏ رَحِمَهُ اللَّهُ، لَقَدْ أَذْكَرَنِي كَذَا وَكَذَا آيَةً أَسْقَطْتُهَا فِي سُورَةِ كَذَا وَكَذَا ‏"‏‏.‏\hadithno{6335}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) heard a man reciting (the Qur'an) in the mosque. He said," May Allah bestow His Mercy on him, as he made me remember such and-such Verse which I had missed in such-and-such Sura}}
\hadithdefcmd{bukhari}{6336}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي سُلَيْمَانُ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَسَمَ النَّبِيُّ صلى الله عليه وسلم قَسْمًا فَقَالَ رَجُلٌ إِنَّ هَذِهِ لَقِسْمَةٌ مَا أُرِيدَ بِهَا وَجْهُ اللَّهِ‏.‏ فَأَخْبَرْتُ النَّبِيَّ صلى الله عليه وسلم فَغَضِبَ حَتَّى رَأَيْتُ الْغَضَبَ فِي وَجْهِهِ وَقَالَ ‏ "‏ يَرْحَمُ اللَّهُ مُوسَى، لَقَدْ أُوذِيَ بِأَكْثَرَ مِنْ هَذَا فَصَبَرَ ‏"‏‏.‏\hadithno{6336}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) divided something (among the Muslims) and distributed the shares (of the booty). A man said, "This division has not been made to please Allah." When I informed the Prophet (ﷺ) about it, he became so furious that I noticed the signs of anger on his face and he then said, "May Allah bestow His Mercy on Moses, for he was hurt with more than this, yet he remained patient}}
\hadithdefcmd{bukhari}{6337}{حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدِ بْنِ السَّكَنِ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ أَبُو حَبِيبٍ، حَدَّثَنَا هَارُونُ الْمُقْرِئُ، حَدَّثَنَا الزُّبَيْرُ بْنُ الْخِرِّيتِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدِّثِ النَّاسَ، كُلَّ جُمُعَةٍ مَرَّةً، فَإِنْ أَبَيْتَ فَمَرَّتَيْنِ، فَإِنَّ أَكْثَرْتَ فَثَلاَثَ مِرَارٍ وَلاَ تُمِلَّ النَّاسَ هَذَا الْقُرْآنَ، وَلاَ أُلْفِيَنَّكَ تَأْتِي الْقَوْمَ وَهُمْ فِي حَدِيثٍ مِنْ حَدِيثِهِمْ فَتَقُصُّ عَلَيْهِمْ، فَتَقْطَعُ عَلَيْهِمْ حَدِيثَهُمْ فَتُمِلُّهُمْ، وَلَكِنْ أَنْصِتْ، فَإِذَا أَمَرُوكَ فَحَدِّثْهُمْ وَهُمْ يَشْتَهُونَهُ، فَانْظُرِ السَّجْعَ مِنَ الدُّعَاءِ فَاجْتَنِبْهُ، فَإِنِّي عَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَصْحَابَهُ لاَ يَفْعَلُونَ إِلاَّ ذَلِكَ‏.‏ يَعْنِي لاَ يَفْعَلُونَ إِلاَّ ذَلِكَ الاِجْتِنَابَ‏.‏\hadithno{6337}\hadithtrans{Narrated `Ikrima:Ibn `Abbas said, "Preach to the people once a week, and if you won't, then preach them twice, but if you want to preach more, then let it be three times (a week only), and do not make the people fed-up with this Qur'an. If you come to some people who are engaged in a talk, don't start interrupting their talk by preaching, lest you should cause them to be bored. You should rather keep quiet, and if they ask you, then preach to them at the time when they are eager to hear what you say. And avoid the use of rhymed prose in invocation for I noticed that Allah's Messenger (ﷺ) and his companions always avoided it}}
\hadithdefcmd{bukhari}{6338}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَعَا أَحَدُكُمْ فَلْيَعْزِمِ الْمَسْأَلَةَ، وَلاَ يَقُولَنَّ اللَّهُمَّ إِنْ شِئْتَ فَأَعْطِنِي‏.‏ فَإِنَّهُ لاَ مُسْتَكْرِهَ لَهُ ‏"‏‏.‏\hadithno{6338}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "When anyone of you appeal to Allah for something, he should ask with determination and should not say, 'O Allah, if You wish, give me.', for nobody can force Allah to do something against His Will}}
\hadithdefcmd{bukhari}{6339}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمُ اللَّهُمَّ اغْفِرْ لِي، اللَّهُمَّ ارْحَمْنِي، إِنْ شِئْتَ‏.‏ لِيَعْزِمِ الْمَسْأَلَةَ، فَإِنَّهُ لاَ مُكْرِهَ لَهُ ‏"‏‏.‏\hadithno{6339}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "None of you should say: 'O Allah, forgive me if You wish; O Allah, be merciful to me if You wish,' but he should always appeal to Allah with determination, for nobody can force Allah to do something against His Will}}
\hadithdefcmd{bukhari}{6340}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى ابْنِ أَزْهَرَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُسْتَجَابُ لأَحَدِكُمْ مَا لَمْ يَعْجَلْ يَقُولُ دَعَوْتُ فَلَمْ يُسْتَجَبْ لِي ‏"‏‏.‏\hadithno{6340}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The invocation of anyone of you is granted (by Allah) if he does not show impatience (by saying, "I invoked Allah but my request has not been granted)}}
\hadithdefcmd{bukhari}{6341}{قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ الأُوَيْسِيُّ حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَشَرِيكٍ، سَمِعَا أَنَسًا، عَنِ النَّبِيِّ صلى الله عليه وسلم رَفَعَ يَدَيْهِ حَتَّى رَأَيْتُ بَيَاضَ إِبْطَيْهِ‏.‏\hadithno{6341}\hadithtrans{Narrated Anas, "The Prophet (ﷺ) raised his hands (in invocation) till I saw the whiteness of his armpits}}
\hadithdefcmd{bukhari}{6342}{حَدَّثَنَا مُحَمَّدُ بْنُ مَحْبُوبٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَسْقِيَنَا‏.‏ فَتَغَيَّمَتِ السَّمَاءُ وَمُطِرْنَا، حَتَّى مَا كَادَ الرَّجُلُ يَصِلُ إِلَى مَنْزِلِهِ، فَلَمْ تَزَلْ تُمْطَرُ إِلَى الْجُمُعَةِ الْمُقْبِلَةِ، فَقَامَ ذَلِكَ الرَّجُلُ أَوْ غَيْرُهُ فَقَالَ ادْعُ اللَّهَ أَنْ يَصْرِفَهُ عَنَّا، فَقَدْ غَرِقْنَا‏.‏ فَقَالَ ‏ "‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏‏.‏ فَجَعَلَ السَّحَابُ يَتَقَطَّعُ حَوْلَ الْمَدِينَةِ، وَلاَ يُمْطِرُ أَهْلَ الْمَدِينَةِ‏.‏\hadithno{6342}\hadithtrans{Narrated Anas:While the Prophet (ﷺ) was delivering a sermon on a Friday, a man stood up and said, "O Allah's Messenger (ﷺ)! Invoke Allah to bless us with rain." (The Prophet (ﷺ) invoked Allah for rain.) So, the sky became overcast and it started raining till one could hardly reach one's home. It kept on raining till the next Friday when the same man or another man got up and said (to the Prophet), "Invoke Allah to withhold the rain from us, for we have been drowned (with heavy rain )." The Prophet (ﷺ) said, "O Allah! Let it rain around us and not on us." Then the clouds started dispersing around Medina and rain ceased to fall on the people of Medina}}
\hadithdefcmd{bukhari}{6343}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم إِلَى هَذَا الْمُصَلَّى يَسْتَسْقِي، فَدَعَا وَاسْتَسْقَى ثُمَّ اسْتَقْبَلَ الْقِبْلَةَ وَقَلَبَ رِدَاءَهُ‏.‏\hadithno{6343}\hadithtrans{Narrated `Abdullah bin Zaid:Allah's Messenger (ﷺ) went out to this Musalla (praying place) to offer the prayer of Istisqa.' He invoked Allah for rain and then faced the Qibla and turned his Rida' (upper garment) inside out}}
\hadithdefcmd{bukhari}{6344}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا حَرَمِيٌّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَتْ أُمِّي يَا رَسُولَ اللَّهِ خَادِمُكَ أَنَسٌ ادْعُ اللَّهَ لَهُ‏.‏ قَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ، وَبَارِكْ لَهُ فِيمَا أَعْطَيْتَهُ ‏"‏‏.‏\hadithno{6344}\hadithtrans{Narrated Anas:My mother said, "O Allah's Messenger (ﷺ)! Please invoke Allah on behalf of your servant." He said, "O Allah! Increase his wealth and children, and bestow Your Blessing on whatever You give him." a time of distress}}
\hadithdefcmd{bukhari}{6345}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْعُو عِنْدَ الْكَرْبِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ الْعَظِيمُ الْحَلِيمُ، لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ السَّمَوَاتِ وَالأَرْضِ، رَبُّ الْعَرْشِ الْعَظِيمِ ‏"‏‏.‏\hadithno{6345}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) used to invoke Allah at the time of distress, saying, "La ilaha illal-lahu Al-`Azim, al- Halim, La ilaha illal-lahu Rabbu-s-samawati wal-ard wa Rabbu-l-arsh il-azim}}
\hadithdefcmd{bukhari}{6346}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامِ بْنِ أَبِي عَبْدِ اللَّهِ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ عِنْدَ الْكَرْبِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ الْعَظِيمُ الْحَلِيمُ، لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ الْعَرْشِ الْعَظِيمِ، لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ السَّمَوَاتِ، وَرَبُّ الأَرْضِ، وَرَبُّ الْعَرْشِ الْكَرِيمِ ‏"‏‏.‏ وَقَالَ وَهْبٌ حَدَّثَنَا شُعْبَةُ عَنْ قَتَادَةَ مِثْلَهُ‏.‏\hadithno{6346}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) used to say at a time of distress, "La ilaha illal-lahu Rabbul-l-'arsh il-'azim, La ilaha illallahu Rabbu-s-samawati wa Rabbu-l-ard, Rabbu-l-'arsh-il-Karim}}
\hadithdefcmd{bukhari}{6347}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي سُمَىٌّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَعَوَّذُ مِنْ جَهْدِ الْبَلاَءِ، وَدَرَكِ الشَّقَاءِ، وَسُوءِ الْقَضَاءِ، وَشَمَاتَةِ الأَعْدَاءِ‏.‏ قَالَ سُفْيَانُ الْحَدِيثُ ثَلاَثٌ زِدْتُ أَنَا وَاحِدَةً، لاَ أَدْرِي أَيَّتُهُنَّ هِيَ‏.‏\hadithno{6347}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) used to seek refuge with Allah from the difficult moment of a calamity and from being overtaken by destruction and from being destined to an evil end, and from the malicious joy of enemies. Sufyan said, "This narration contained three items only, but I added one. I do not know which one that was}}
\hadithdefcmd{bukhari}{6348}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَعُرْوَةُ بْنُ الزُّبَيْرِ، فِي رِجَالٍ مِنْ أَهْلِ الْعِلْمِ أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ وَهْوَ صَحِيحٌ ‏"‏ لَنْ يُقْبَضَ نَبِيٌّ قَطُّ حَتَّى يَرَى مَقْعَدَهُ مِنَ الْجَنَّةِ ثُمَّ يُخَيَّرُ ‏"‏‏.‏ فَلَمَّا نَزَلَ بِهِ وَرَأْسُهُ عَلَى فَخِذِي، غُشِيَ عَلَيْهِ سَاعَةً، ثُمَّ أَفَاقَ فَأَشْخَصَ بَصَرَهُ إِلَى السَّقْفِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ الرَّفِيقَ الأَعْلَى ‏"‏‏.‏ قُلْتُ إِذًا لاَ يَخْتَارُنَا، وَعَلِمْتُ أَنَّهُ الْحَدِيثُ الَّذِي كَانَ يُحَدِّثُنَا، وَهْوَ صَحِيحٌ‏.‏ قَالَتْ فَكَانَتْ تِلْكَ آخِرَ كَلِمَةٍ تَكَلَّمَ بِهَا ‏"‏ اللَّهُمَّ الرَّفِيقَ الأَعْلَى ‏"‏‏.‏\hadithno{6348}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) was healthy, he used to say, "No prophet dies till he is shown his place in Paradise, and then he is given the option (to live or die)." So when death approached him(during his illness), and while his head was on my thigh, he became unconscious for a while, and when he recovered, he fixed his eyes on the ceiling and said, "O Allah! (Let me join) the Highest Companions (see Qur'an 4:69)," I said, "So, he does not choose us." Then I realized that it was the application of the statement he used to relate to us when he was healthy. So that was his last utterance (before he died), i.e. "O Allah! (Let me join) the Highest Companions}}
\hadithdefcmd{bukhari}{6349}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ أَتَيْتُ خَبَّابًا وَقَدِ اكْتَوَى سَبْعًا قَالَ لَوْلاَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا أَنْ نَدْعُوَ بِالْمَوْتِ لَدَعَوْتُ بِهِ‏.‏\hadithno{6349}\hadithtrans{Narrated Qais:I came to Khabbab who had been branded with seven brands(1) and he said, "Had Allah's Messenger (ﷺ) not forbidden us to invoke (Allah) for death, I would have invoked (Allah) for it}}
\hadithdefcmd{bukhari}{6350}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسٌ، قَالَ أَتَيْتُ خَبَّابًا وَقَدِ اكْتَوَى سَبْعًا فِي بَطْنِهِ فَسَمِعْتُهُ يَقُولُ لَوْلاَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَانَا أَنْ نَدْعُوَ بِالْمَوْتِ لَدَعَوْتُ بِهِ‏.‏\hadithno{6350}\hadithtrans{Narrated Qais:I came to Khabbab who had been branded with seven brands over his `Abdomen, and I heard him saying, "If the Prophet: had not forbidden us to invoke (Allah) for death, I would have invoked Allah for it}}
\hadithdefcmd{bukhari}{6351}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدٌ مِنْكُمُ الْمَوْتَ لِضُرٍّ نَزَلَ بِهِ، فَإِنْ كَانَ لاَ بُدَّ مُتَمَنِّيًا لِلْمَوْتِ فَلْيَقُلِ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي، وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏"‏‏.‏\hadithno{6351}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said," None of you should long for death because of a calamity that had befallen him, and if he cannot, but long for death, then he should say, 'O Allah! Let me live as long as life is better for me, and take my life if death is better for me}}
\hadithdefcmd{bukhari}{6352}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، عَنِ الْجَعْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، يَقُولُ ذَهَبَتْ بِي خَالَتِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَ أُخْتِي وَجِعٌ‏.‏ فَمَسَحَ رَأْسِي، وَدَعَا لِي بِالْبَرَكَةِ، ثُمَّ تَوَضَّأَ فَشَرِبْتُ مِنْ وَضُوئِهِ، ثُمَّ قُمْتُ خَلْفَ ظَهْرِهِ، فَنَظَرْتُ إِلَى خَاتَمِهِ بَيْنَ كَتِفَيْهِ مِثْلَ زِرِّ الْحَجَلَةِ‏.‏\hadithno{6352}\hadithtrans{Narrated As-Sa'ib bin Yazid:My aunt took me to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! My sister's son is sick." So he passed his hand over my head and invoked for Allah's blessing upon me and then performed the ablution. I drank from the water of his ablution and I stood behind him and looked at his Khatam (the seal of Prophethood) between his shoulders (and its size was) like the button of a tent}}
\hadithdefcmd{bukhari}{6353}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ أَبِي عَقِيلٍ، أَنَّهُ كَانَ يَخْرُجُ بِهِ جَدُّهُ عَبْدُ اللَّهِ بْنُ هِشَامٍ مِنَ السُّوقِ أَوْ إِلَى السُّوقِ فَيَشْتَرِي الطَّعَامَ، فَيَلْقَاهُ ابْنُ الزُّبَيْرِ وَابْنُ عُمَرَ فَيَقُولاَنِ أَشْرِكْنَا فَإِنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ دَعَا لَكَ بِالْبَرَكَةِ‏.‏ فَرُبَّمَا أَصَابَ الرَّاحِلَةَ كَمَا هِيَ، فَيَبْعَثُ بِهَا إِلَى الْمَنْزِلِ‏.‏\hadithno{6353}\hadithtrans{Narrated Abu `Aqil:that his grandfather. `Abdullah bin Hisham used to take him from the market or to the market (the narrator is in doubt) and used to buy grain and when Ibn Az-Zubair and Ibn `Umar met him, they would say to him, "Let us be your partners (in trading) as the Prophet (ﷺ) invoked for Allah's blessing upon you." He would then take them as partners and he would Sometimes gain a whole load carried by an animal which he would send home}}
\hadithdefcmd{bukhari}{6354}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ، وَهُوَ الَّذِي مَجَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي وَجْهِهِ وَهْوَ غُلاَمٌ مِنْ بِئْرِهِمْ‏.‏\hadithno{6354}\hadithtrans{Narrated Mahmud bin Ar-Rabi:On whose face Allah's Messenger (ﷺ) had thrown water from his mouth, the water having been taken from their well while he was still a young boy (who has not yet attained the age of puberty)}}
\hadithdefcmd{bukhari}{6355}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُؤْتَى بِالصِّبْيَانِ فَيَدْعُو لَهُمْ، فَأُتِيَ بِصَبِيٍّ فَبَالَ عَلَى ثَوْبِهِ، فَدَعَا بِمَاءٍ فَأَتْبَعَهُ إِيَّاهُ، وَلَمْ يَغْسِلْهُ‏.‏\hadithno{6355}\hadithtrans{Narrated `Aisha:The boys used to be brought to the Prophet (ﷺ) and he used to invoke for Allah's blessing upon them. Once an infant was brought to him and it urinated on his clothes. He asked for water and poured it over the place of the urine and did not wash his clothes}}
\hadithdefcmd{bukhari}{6356}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهُ بْنُ ثَعْلَبَةَ بْنِ صُعَيْرٍ ـ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ مَسَحَ عَنْهُ ـ أَنَّهُ رَأَى سَعْدَ بْنَ أَبِي وَقَّاصٍ يُوتِرُ بِرَكْعَةٍ‏.‏\hadithno{6356}\hadithtrans{Narrated `Abdullah bin Tha`laba bin Su'air:whose eye Allah's Messenger (ﷺ) had touched, that he had seen Sa`d bin Abi Waqqas offering one rak`a only for the witr prayer}}
\hadithdefcmd{bukhari}{6357}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الْحَكَمُ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، قَالَ لَقِيَنِي كَعْبُ بْنُ عُجْرَةَ فَقَالَ أَلاَ أُهْدِي لَكَ هَدِيَّةً، إِنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ عَلَيْنَا فَقُلْنَا يَا رَسُولَ اللَّهِ قَدْ عَلِمْنَا كَيْفَ نُسَلِّمُ عَلَيْكَ، فَكَيْفَ نُصَلِّي عَلَيْكَ قَالَ ‏ "‏ فَقُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ، وَعَلَى آلِ مُحَمَّدٍ، كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ، اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ، وَعَلَى آلِ مُحَمَّدٍ، كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏‏.‏\hadithno{6357}\hadithtrans{Narrated `Abdur-Rahman bin Abi Laila:Ka`b bin 'Ujra met me and said, "Shall I give you a present? Once the Prophet (ﷺ) came to us and we said, 'O Allah's Messenger (ﷺ) ! We know how to greet you; but how to send 'Salat' upon you? He said, 'Say: Allahumma Salli ala Muhammadin wa 'ala `Ali Muhammadin, kama sal-laita 'ala all Ibrahima innaka Hamidun Majid. Allahumma barik 'ala Muhammadin wa 'ala all Muhammadin, kama barakta 'ala all Ibrahima, innaka Hamidun Majid}}
\hadithdefcmd{bukhari}{6358}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، وَالدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ هَذَا السَّلاَمُ عَلَيْكَ، فَكَيْفَ نُصَلِّي قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ عَبْدِكَ وَرَسُولِكَ، كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ، وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ، كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ وَآلِ إِبْرَاهِيمَ ‏"‏‏.‏\hadithno{6358}\hadithtrans{Narrated Abu Sa`id Al-Khudri:We said, "O Allah's Messenger (ﷺ) This is (i.e. we know) the greeting to you; will you tell us how to send Salat on you?" He said, "Say: 'Allahumma Salli 'ala Muhammadin `Abdika wa rasulika kama sal-laita 'ala Ibrahima wa barik 'ala Muhammadin wa all Muhammadin kama barakta 'ala Ibrahima wa `Ali Ibrahim}}
\hadithdefcmd{bukhari}{6359}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ كَانَ إِذَا أَتَى رَجُلٌ النَّبِيَّ صلى الله عليه وسلم بِصَدَقَتِهِ قَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَيْهِ‏"‏ فَأَتَاهُ أَبِي بِصَدَقَتِهِ فَقَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ أَبِي أَوْفَى‏"‏\hadithno{6359}\hadithtrans{Narrated Ibn Abi `Aufa:Whenever somebody brought alms to the Prophet (ﷺ) the used to say, "Allahumma Salli 'Alaihi (O Allah! Send Your Salat (Grace and Honor) on him)." Once when my father brought his alms to him, he said, "O Allah! Send Your Salat (Grace and Honor) on the family of Abi `Aufa}}
\hadithdefcmd{bukhari}{6360}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، قَالَ أَخْبَرَنِي أَبُو حُمَيْدٍ السَّاعِدِيُّ، أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ نُصَلِّي عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ، كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ، وَبَارِكْ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ، كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏‏.‏\hadithno{6360}\hadithtrans{Narrated Abu Humaid As-Saidi:The people said, "O Allah's Messenger (ﷺ) ! How may we send Salat on you?" He said, "Say: Allahumma Salli 'ala- Muhammadin wa azwajihi wa dhurriyyatihi kama sal-laita 'ala `Ali Ibrahim; wa barik 'ala Muhammadin wa azwajihi wa dhurriyyatihi kamabarakta 'ala `Ali Ibrahim innaka hamidun majid}}
\hadithdefcmd{bukhari}{6361}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ فَأَيُّمَا مُؤْمِنٍ سَبَبْتُهُ فَاجْعَلْ ذَلِكَ لَهُ قُرْبَةً إِلَيْكَ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{6361}\hadithtrans{Narrated Abu Huraira:that he heard the Prophet (ﷺ) saying, "O Allah! If I should ever abuse a believer, please let that be a means of bringing him near to You on the Day of Resurrection}}
\hadithdefcmd{bukhari}{6362}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم حَتَّى أَحْفَوْهُ الْمَسْأَلَةَ فَغَضِبَ فَصَعِدَ الْمِنْبَرَ فَقَالَ ‏"‏ لاَ تَسْأَلُونِي الْيَوْمَ عَنْ شَىْءٍ إِلاَّ بَيَّنْتُهُ لَكُمْ ‏"‏‏.‏ فَجَعَلْتُ أَنْظُرُ يَمِينًا وَشِمَالاً، فَإِذَا كُلُّ رَجُلٍ لاَفٌّ رَأْسَهُ فِي ثَوْبِهِ يَبْكِي، فَإِذَا رَجُلٌ كَانَ إِذَا لاَحَى الرِّجَالَ يُدْعَى لِغَيْرِ أَبِيهِ فَقَالَ يَا رَسُولَ اللَّهِ مَنْ أَبِي قَالَ ‏"‏ حُذَافَةُ ‏"‏، ثُمَّ أَنْشَأَ عُمَرُ فَقَالَ رَضِينَا بِاللَّهِ رَبًّا، وَبِالإِسْلاَمِ دِينًا، وَبِمُحَمَّدٍ صلى الله عليه وسلم رَسُولاً، نَعُوذُ بِاللَّهِ مِنَ الْفِتَنِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا رَأَيْتُ فِي الْخَيْرِ وَالشَّرِّ كَالْيَوْمِ قَطُّ، إِنَّهُ صُوِّرَتْ لِي الْجَنَّةُ وَالنَّارُ حَتَّى رَأَيْتُهُمَا وَرَاءَ الْحَائِطِ ‏"‏‏.‏ وَكَانَ قَتَادَةُ يَذْكُرُ عِنْدَ الْحَدِيثِ هَذِهِ الآيَةَ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَسْأَلُوا عَنْ أَشْيَاءَ إِنْ تُبْدَ لَكُمْ تَسُؤْكُمْ‏\}‏‏.‏\hadithno{6362}\hadithtrans{Narrated Anas:Once the people started asking Allah's Messenger (ﷺ) questions, and they asked so many questions that he became angry and ascended the pulpit and said, "I will answer whatever questions you may ask me today." I looked right and left and saw everyone covering his face with his garment and weeping. Behold ! There was a man who, on quarreling with the people, used to be called as a son of a person other than h is father. He said, "O Allah's Messenger (ﷺ)! Who is my father?" The Prophet (ﷺ) replied, "Your father is Hudhaifa." And then `Umar got up and said, "We accept Allah as our Lord, and Islam as (our) religion, and Muhammad as (our) Apostle; and we seek refuge with Allah from the afflictions." Allah's Messenger (ﷺ) said, " I have never seen a day like today in its good and its evil for Paradise and the Hell Fire were displayed in front of me, till I saw them just beyond this wall." Qatada, when relating this Hadith, used to mention the following Verse:-- 'O you who believe! Ask not questions about things which, If made plain to you, May cause you trouble}}
\hadithdefcmd{bukhari}{6363}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَبِي طَلْحَةَ ‏"‏ الْتَمِسْ لَنَا غُلاَمًا مِنْ غِلْمَانِكُمْ يَخْدُمُنِي ‏"‏‏.‏ فَخَرَجَ بِي أَبُو طَلْحَةَ يُرْدِفُنِي وَرَاءَهُ، فَكُنْتُ أَخْدُمُ رَسُولَ اللَّهِ صلى الله عليه وسلم كُلَّمَا نَزَلَ، فَكُنْتُ أَسْمَعُهُ يُكْثِرُ أَنْ يَقُولَ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ، وَالْعَجْزِ وَالْكَسَلِ، وَالْبُخْلِ وَالْجُبْنِ، وَضَلَعِ الدَّيْنِ، وَغَلَبَةِ الرِّجَالِ ‏"‏‏.‏ فَلَمْ أَزَلْ أَخْدُمُهُ حَتَّى أَقْبَلْنَا مِنْ خَيْبَرَ، وَأَقْبَلَ بِصَفِيَّةَ بِنْتِ حُيَىٍّ قَدْ حَازَهَا، فَكُنْتُ أَرَاهُ يُحَوِّي وَرَاءَهُ بِعَبَاءَةٍ أَوْ كِسَاءٍ ثُمَّ يُرْدِفُهَا وَرَاءَهُ حَتَّى إِذَا كُنَّا بِالصَّهْبَاءِ صَنَعَ حَيْسًا فِي نِطَعٍ، ثُمَّ أَرْسَلَنِي فَدَعَوْتُ رِجَالاً فَأَكَلُوا، وَكَانَ ذَلِكَ بِنَاءَهُ بِهَا، ثُمَّ أَقْبَلَ حَتَّى بَدَا لَهُ أُحُدٌ قَالَ ‏"‏ هَذَا جُبَيْلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏‏.‏ فَلَمَّا أَشْرَفَ عَلَى الْمَدِينَةِ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أُحَرِّمُ مَا بَيْنَ جَبَلَيْهَا مِثْلَ مَا حَرَّمَ بِهِ إِبْرَاهِيمُ مَكَّةَ، اللَّهُمَّ بَارِكْ لَهُمْ فِي مُدِّهِمْ وَصَاعِهِمْ ‏"‏‏.‏\hadithno{6363}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said to Abu Talha, "Choose one of your boys to serve me." So Abu Talha took me (to serve the Prophet (ﷺ) ) by giving me a ride behind him (on his camel). So I used to serve Allah's Messenger (ﷺ) whenever he stayed somewhere. I used to hear him saying, "O Allah! I seek refuge with you (Allah) from (worries) care and grief, from incapacity and laziness, from miserliness and cowardice, from being heavily in debt and from being overpowered by other men." I kept on serving him till he returned from (the battle of) Khaibar. He then brought Safiya, the daughter of Huyay whom he had got (from the booty). I saw him making a kind of cushion with a cloak or a garment for her. He then let her ride behind him. When we reached a place called As-Sahba', he prepared (a special meal called) Hais, and asked me to invite the men who (came and) ate, and that was the marriage banquet given on the consummation of his marriage to her. Then he proceeded till the mountain of Uhud appeared, whereupon he said, "This mountain loves us and we love it." When he approached Medina, he said, "O Allah! I make the land between its (i.e., Medina's) two mountains a sanctuary, as the prophet Abraham made Mecca a sanctuary. O Allah! Bless them (the people of Medina) in their Mudd and the Sa' (units of measuring)}}
\hadithdefcmd{bukhari}{6364}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، قَالَ سَمِعْتُ أُمَّ خَالِدٍ بِنْتَ خَالِدٍ ـ قَالَ وَلَمْ أَسْمَعْ أَحَدًا سَمِعَ مِنَ النَّبِيِّ، صلى الله عليه وسلم غَيْرَهَا ـ قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَتَعَوَّذُ مِنْ عَذَابِ الْقَبْرِ‏.‏\hadithno{6364}\hadithtrans{Narrated Um Khalid bint Khalid:I heard the Prophet (ﷺ) seeking refuge with Allah from the punishment of the grave}}
\hadithdefcmd{bukhari}{6365}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ مُصْعَبٍ، كَانَ سَعْدٌ يَأْمُرُ بِخَمْسٍ وَيَذْكُرُهُنَّ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَأْمُرُ بِهِنَّ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ، وَأَعُوذُ بِكَ مِنَ الْجُبْنِ، وَأَعُوذُ بِكَ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا يَعْنِي فِتْنَةَ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ ‏"‏‏.‏\hadithno{6365}\hadithtrans{Narrated Mus`ab:Sa`d used to recommend five (statements) and mentioned that the Prophet (ﷺ) I used to recommend it. (It was) "O Allah! I seek refuge with You from miserliness; and seek refuge with You from cowardice; and seek refuge with You from being sent back to geriatric old age; and I seek refuge with You from the affliction of this world (i.e., the affliction of Ad-Dajjal etc.); and seek refuge with You from the punishment of the grave}}
\hadithdefcmd{bukhari}{6366}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَتْ عَلَىَّ عَجُوزَانِ مِنْ عُجُزِ يَهُودِ الْمَدِينَةِ فَقَالَتَا لِي إِنَّ أَهْلَ الْقُبُورِ يُعَذَّبُونَ فِي قُبُورِهِمْ، فَكَذَّبْتُهُمَا، وَلَمْ أُنْعِمْ أَنْ أُصَدِّقَهُمَا، فَخَرَجَتَا وَدَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ لَهُ يَا رَسُولَ اللَّهِ إِنَّ عَجُوزَيْنِ وَذَكَرْتُ لَهُ، فَقَالَ ‏ "‏ صَدَقَتَا، إِنَّهُمْ يُعَذَّبُونَ عَذَابًا تَسْمَعُهُ الْبَهَائِمُ كُلُّهَا ‏"‏‏.‏ فَمَا رَأَيْتُهُ بَعْدُ فِي صَلاَةٍ إِلاَّ تَعَوَّذَ مِنْ عَذَابِ الْقَبْرِ‏.‏\hadithno{6366}\hadithtrans{Narrated `Aisha:Two old ladies from among the Jewish ladies entered upon me and said' "The dead are punished in their graves," but I thought they were telling a lie and did not believe them in the beginning. When they went away and the Prophet (ﷺ) entered upon me, I said, "O Allah's Messenger (ﷺ)! Two old ladies.." and told him the whole story. He said, "They told the truth; the dead are really punished, to the extent that all the animals hear (the sound resulting from) their punishment." Since then I always saw him seeking refuge with Allah from the punishment of the grave in his prayers}}
\hadithdefcmd{bukhari}{6367}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي قَالَ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ، وَالْجُبْنِ وَالْهَرَمِ، وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏‏.‏\hadithno{6367}\hadithtrans{Narrated Anas bin Malik:Allah's Prophet used to say, "O Allah! I seek refuge with You from incapacity and laziness, from cowardice and geriatric old age, and seek refuge with You from the punishment of the grave, and I seek refuge with You from the afflictions of life and death}}
\hadithdefcmd{bukhari}{6368}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ، وَالْمَأْثَمِ وَالْمَغْرَمِ، وَمِنْ فِتْنَةِ الْقَبْرِ وَعَذَابِ الْقَبْرِ، وَمِنْ فِتْنَةِ النَّارِ وَعَذَابِ النَّارِ، وَمِنْ شَرِّ فِتْنَةِ الْغِنَى، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْفَقْرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ، اللَّهُمَّ اغْسِلْ عَنِّي خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ، وَنَقِّ قَلْبِي مِنَ الْخَطَايَا، كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ، وَبَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ ‏"‏‏.‏\hadithno{6368}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to say, "O Allah! I seek refuge with You from laziness and geriatric old age, from all kinds of sins and from being in debt; from the trial and affliction of the grave and from the punishment in the grave; from the affliction of the Fire and from the punishment of the Fire; and from the evil of the affliction of wealth; and I seek refuge with You from the affliction of poverty, and I seek refuge with You from the affliction of Al-Mesiah Ad-Dajjal. O Allah! Wash away my sins with the water of snow and hail, and cleanse my heart from all the sins as a white garment is cleansed from the filth, and let there be a long distance between me and my sins, as You made East and West far from each other}}
\hadithdefcmd{bukhari}{6369}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي عَمْرُو بْنُ أَبِي عَمْرٍو، قَالَ سَمِعْتُ أَنَسًا، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ، وَالْعَجْزِ وَالْكَسَلِ، وَالْجُبْنِ وَالْبُخْلِ، وَضَلَعِ الدَّيْنِ، وَغَلَبَةِ الرِّجَالِ ‏"‏‏.‏\hadithno{6369}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) used to say, "O Allah! I seek refuge with You from worry and grief, from incapacity and laziness, from cowardice and miserliness, from being heavily in debt and from being overpowered by (other) men." (See Hadith No)}}
\hadithdefcmd{bukhari}{6370}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ ـ رضى الله عنه ـ كَانَ يَأْمُرُ بِهَؤُلاَءِ الْخَمْسِ، وَيُحَدِّثُهُنَّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ، وَأَعُوذُ بِكَ مِنَ الْجُبْنِ، وَأَعُوذُ بِكَ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا، وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ ‏"‏‏.‏\hadithno{6370}\hadithtrans{Narrated Mus`ab bin Sa`d:Sa`d bin Abi Waqqas used to recommend these five (statements) and say that the Prophet (ﷺ) said so (and they are): "O Allah! I seek refuge with You from miserliness, and seek refuge with You from cowardice, and seek refuge with You from being brought back to geriatric old age, and seek refuge with You from the afflictions of the world, and seek refuge with You from the punishment of the grave}}
\hadithdefcmd{bukhari}{6371}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَعَوَّذُ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ، وَأَعُوذُ بِكَ مِنَ الْجُبْنِ، وَأَعُوذُ بِكَ مِنَ الْهَرَمِ، وَأَعُوذُ بِكَ مِنَ الْبُخْلِ ‏"‏‏.‏\hadithno{6371}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) used to seek refuge with Allah saying, "O Allah! I seek refuge with You from laziness, and seek refuge with You from cowardice, and seek refuge with You from geriatric old age, and seek refuge with You from miserliness}}
\hadithdefcmd{bukhari}{6372}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ حَبِّبْ إِلَيْنَا الْمَدِينَةَ، كَمَا حَبَّبْتَ إِلَيْنَا مَكَّةَ أَوْ أَشَدَّ، وَانْقُلْ حُمَّاهَا إِلَى الْجُحْفَةِ، اللَّهُمَّ بَارِكْ لَنَا فِي مُدِّنَا وَصَاعِنَا ‏"‏‏.‏\hadithno{6372}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "O Allah! Make us love Medina as You made us love Mecca, or more, and transfer the fever that is in it, to Al-Juhfa. O Allah! Bless our Mudd and our Sam' (kinds of measures)}}
\hadithdefcmd{bukhari}{6373}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، أَنَّ أَبَاهُ، قَالَ عَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ مِنْ شَكْوَى، أَشْفَيْتُ مِنْهَا عَلَى الْمَوْتِ، فَقُلْتُ يَا رَسُولَ اللَّهِ بَلَغَ بِي مَا تَرَى مِنَ الْوَجَعِ، وَأَنَا ذُو مَالٍ، وَلاَ يَرِثُنِي إِلاَّ ابْنَةٌ لِي وَاحِدَةٌ، أَفَأَتَصَدَّقُ بِثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَبِشَطْرِهِ قَالَ ‏"‏ الثُّلُثُ كَثِيرٌ، إِنَّكَ أَنْ تَذَرَ وَرَثَتَكَ أَغْنِيَاءَ، خَيْرٌ مِنْ أَنْ تَذَرَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ، وَإِنَّكَ لَنْ تُنْفِقَ نَفَقَةً تَبْتَغِي بِهَا وَجْهَ اللَّهِ، إِلاَّ أُجِرْتَ، حَتَّى مَا تَجْعَلُ فِي فِي امْرَأَتِكَ ‏"‏‏.‏ قُلْتُ أَأُخَلَّفُ بَعْدَ أَصْحَابِي قَالَ ‏"‏ إِنَّكَ لَنْ تُخَلَّفَ فَتَعْمَلَ عَمَلاً تَبْتَغِي بِهِ وَجْهَ اللَّهِ، إِلاَّ ازْدَدْتَ دَرَجَةً وَرِفْعَةً وَلَعَلَّكَ تُخَلَّفُ حَتَّى يَنْتَفِعَ بِكَ أَقْوَامٌ، وَيُضَرَّ بِكَ آخَرُونَ، اللَّهُمَّ أَمْضِ لأَصْحَابِي هِجْرَتَهُمْ، وَلاَ تَرُدَّهُمْ عَلَى أَعْقَابِهِمْ، لَكِنِ الْبَائِسُ سَعْدُ ابْنُ خَوْلَةَ ‏"‏‏.‏ قَالَ سَعْدٌ رَثَى لَهُ النَّبِيُّ صلى الله عليه وسلم مِنْ أَنْ تُوُفِّيَ بِمَكَّةَ‏.‏\hadithno{6373}\hadithtrans{Narrated 'Amir bin Sa`d:that his father said, "In the year of Hajjatal-Wada`, the Prophet (ﷺ) paid me a visit while I was suffering from an ailment that had brought me to the verge of death. I said, 'O Allah's Messenger (ﷺ)! My sickness has reduced me to the (bad) state as you see, and I am a rich man, but have no heirs except one daughter. Shall I give 2/3 of my property in charity?' He said, 'No.' I said, 'Then 1/2 of it?' He said, 'Even 1/3 is too much, for, to leave your inheritors wealthy is better than to leave them in poverty, begging from people. And (know that) whatever you spend in Allah's Cause, you will get reward for it, even for the morsel of food which you put in your wife's mouth.' I said, 'O Allah's Messenger (ﷺ)! Will I be left behind my companions (in Mecca)?' He said, 'If you remain behind, whatever good deed you will do for Allah's Sake, will raise and upgrade you to a higher position (in Allah's Sight). May be you will live longer so that some people may benefit by you, and some e others (pagans) may get harmed by you. O Allah! Complete the migration of my companions and do not turn them on their heels; But (we pity) the poor Sa`d bin Khaula (not the above mentioned Sa`d) (died in Mecca)" Allah's Messenger (ﷺ) lamented (or pitied) for him as he died in Mecca. (See Hadith No. 693, Vol)}}
\hadithdefcmd{bukhari}{6374}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْحُسَيْنُ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ، عَنْ مُصْعَبٍ، عَنْ أَبِيهِ، قَالَ تَعَوَّذُوا بِكَلِمَاتٍ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَعَوَّذُ بِهِنَّ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُبْنِ، وَأَعُوذُ بِكَ مِنَ الْبُخْلِ، وَأَعُوذُ بِكَ مِنْ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا، وَعَذَابِ الْقَبْرِ ‏"‏‏.‏\hadithno{6374}\hadithtrans{Narrated Sa`d:Seek refuge with Allah by saying the words which the Prophet (ﷺ) used to say while seeking refuge with Allah, "0 Allah! I seek refuge with You from cowardice, and seek refuge with You from miserliness, and seek refuge with You from reaching a degraded geriatric old age, and seek refuge with You from the afflictions of the world and from the punishment in the grave}}
\hadithdefcmd{bukhari}{6375}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْمَغْرَمِ وَالْمَأْثَمِ، اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ النَّارِ وَفِتْنَةِ النَّارِ وَعَذَابِ الْقَبْرِ، وَشَرِّ فِتْنَةِ الْغِنَى، وَشَرِّ فِتْنَةِ الْفَقْرِ، وَمِنْ شَرِّ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ، اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ، وَنَقِّ قَلْبِي مِنَ الْخَطَايَا، كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ، وَبَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ ‏"‏‏.‏\hadithno{6375}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to say, "O Allah! I seek refuge with You from laziness from geriatric old age, from being in debt, and from committing sins. O Allah! I seek refuge with You from the punishment of the Fire, the afflictions of the grave, the punishment in the grave, and the evil of the affliction of poverty and from the evil of the affliction caused by Al-Masih Ad-Dajjal. O Allah! Wash away my sins with the water of snow and hail, and cleanse my heart from the sins as a white garment is cleansed of filth, and let there be a far away distance between me and my sins as You have set far away the East and the West from each other}}
\hadithdefcmd{bukhari}{6376}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سَلاَّمُ بْنُ أَبِي مُطِيعٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ خَالَتِهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ النَّارِ وَمِنْ عَذَابِ النَّارِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْقَبْرِ، وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْغِنَى، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْفَقْرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏‏.‏\hadithno{6376}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to seek refuge with Allah (by saying), "O Allah! I seek refuge with You from the affliction of the Fire and from the punishment in the Fire, and seek refuge with You from the affliction of the grave, and I seek refuge with You from the affliction of wealth, and I seek refuge with You from the affliction of poverty, and seek refuge with You from the affliction of Al-Masih Ad-Dajjal}}
\hadithdefcmd{bukhari}{6377}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ النَّارِ وَعَذَابِ النَّارِ، وَفِتْنَةِ الْقَبْرِ وَعَذَابِ الْقَبْرِ، وَشَرِّ فِتْنَةِ الْغِنَى، وَشَرِّ فِتْنَةِ الْفَقْرِ، اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ، اللَّهُمَّ اغْسِلْ قَلْبِي بِمَاءِ الثَّلْجِ وَالْبَرَدِ، وَنَقِّ قَلْبِي مِنَ الْخَطَايَا، كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ، وَبَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ، اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْمَأْثَمِ وَالْمَغْرَمِ ‏"‏‏.‏\hadithno{6377}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to say, 'O Allah! I seek refuge with You from the affliction of the Fire, the punishment of the Fire, the affliction of the grave, the punishment of the grave, and the evil of the affliction of poverty. O Allah! I seek refuge with You from the evil of the affliction of Al-Masih Ad- Dajjal, O Allah! Cleanse my heart with the water of snow and hail, and cleanse my heart from all sins as a white garment is cleansed from filth, and let there be a far away distance between me and my sins as You made the East and West far away from each other. O Allah! I seek refuge with You from laziness, sins, and from being in debt}}
\hadithdefcmd{bukhari}{6379}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ أُمِّ سُلَيْمٍ، أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ أَنَسٌ خَادِمُكَ ادْعُ اللَّهَ لَهُ قَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ، وَبَارِكْ لَهُ فِيمَا أَعْطَيْتَهُ ‏"‏‏.‏ وَعَنْ هِشَامِ بْنِ زَيْدٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، مِثْلَهُ\hadithno{6379}\hadithtrans{Narrated Um Sulaim:that she said, "O Allah's Messenger (ﷺ)! Anas is your servant, so please invoke for Allah's blessing for him." The Prophet (ﷺ) said, "O Allah! Increase his wealth and offspring and bless (for him) whatever You give him}}
\hadithdefcmd{bukhari}{6381}{حَدَّثَنَا أَبُو زَيْدٍ، سَعِيدُ بْنُ الرَّبِيعِ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ قَالَ قَالَتْ أُمُّ سُلَيْمٍ أَنَسٌ خَادِمُكَ‏.‏ قَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ، وَبَارِكْ لَهُ فِيمَا أَعْطَيْتَهُ ‏"‏‏.‏\hadithno{6381}\hadithtrans{Narrated Anas:Um Sulaim said (to the Prophet), "Anas is your servant; so please invoke for Allah's blessings for him." He said "O Allah! Increase his wealth and offspring, and Bless (for him) whatever You give him}}
\hadithdefcmd{bukhari}{6382}{حَدَّثَنَا مُطَرِّفُ بْنُ عَبْدِ اللَّهِ أَبُو مُصْعَبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعَلِّمُنَا الاِسْتِخَارَةَ فِي الأُمُورِ كُلِّهَا كَالسُّورَةِ مِنَ الْقُرْآنِ ‏ "‏ إِذَا هَمَّ بِالأَمْرِ فَلْيَرْكَعْ رَكْعَتَيْنِ، ثُمَّ يَقُولُ اللَّهُمَّ إِنِّي أَسْتَخِيرُكَ بِعِلْمِكَ، وَأَسْتَقْدِرُكَ بِقُدْرَتِكَ، وَأَسْأَلُكَ مِنْ فَضْلِكَ الْعَظِيمِ، فَإِنَّكَ تَقْدِرُ وَلاَ أَقْدِرُ، وَتَعْلَمُ وَلاَ أَعْلَمُ، وَأَنْتَ عَلاَّمُ الْغُيُوبِ، اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ خَيْرٌ لِي فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي ـ أَوْ قَالَ عَاجِلِ أَمْرِي وَآجِلِهِ ـ فَاقْدُرْهُ لِي، وَإِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ شَرٌّ لِي فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي ـ أَوْ قَالَ فِي عَاجِلِ أَمْرِي وَآجِلِهِ ـ فَاصْرِفْهُ عَنِّي وَاصْرِفْنِي عَنْهُ، وَاقْدُرْ لِيَ الْخَيْرَ حَيْثُ كَانَ، ثُمَّ رَضِّنِي بِهِ‏.‏ وَيُسَمِّي حَاجَتَهُ ‏"‏‏.‏\hadithno{6382}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) used to teach us the Istikhara for each and every matter as he used to teach us the Suras from the Holy Qur'an. (He used to say), "If anyone of you intends to do something, he should offer a two-rak`at prayer other than the obligatory prayer, and then say: 'Allahumma inni astakhiruka bi'ilmika, wa astaqdiruka biqudratika, wa as'aluka min fadlika-l-'azim, fa innaka taqdiru wala aqdiru, wa ta'lamu wala a'lamu, wa anta'allamu-l-ghuyub. Allahumma in kunta ta'lamu anna hadha-lamra khairun li fi dini wa ma'ashi wa 'aqibati `Amri (or said, fi 'ajili `Amri wa ajilihi) fa-qdurhu li, Wa in kunta ta'lamu anna ha-dha-l-amra sharrun li fi dini wa ma'ashi wa 'aqibati `Amri (or said, fi ajili `Amri wa ajilihi) fasrifhu 'anni was-rifni 'anhu wa aqdur li alkhaira haithu kana, thumma Raddani bihi," Then he should mention his matter (need)}}
\hadithdefcmd{bukhari}{6383}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ دَعَا النَّبِيُّ صلى الله عليه وسلم بِمَاءٍ فَتَوَضَّأَ، ثُمَّ رَفَعَ يَدَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِعُبَيْدٍ أَبِي عَامِرٍ ‏"‏‏.‏ وَرَأَيْتُ بَيَاضَ إِبْطَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ اجْعَلْهُ يَوْمَ الْقِيَامَةِ فَوْقَ كَثِيرٍ مِنْ خَلْقِكَ مِنَ النَّاسِ ‏"‏‏.‏\hadithno{6383}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) asked for some water and performed the ablution, and then raised his hands (towards the sky) and said, "O Allah! Forgive `Ubaid Abi 'Amir." I saw the whiteness of his armpits (while he was raising his hands) and he added, "O Allah! Upgrade him over many of Your human creatures on the Day of Resurrection}}
\hadithdefcmd{bukhari}{6384}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَكُنَّا إِذَا عَلَوْنَا كَبَّرْنَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَيُّهَا النَّاسُ ارْبَعُوا عَلَى أَنْفُسِكُمْ، فَإِنَّكُمْ لاَ تَدْعُونَ أَصَمَّ وَلاَ غَائِبًا، وَلَكِنْ تَدْعُونَ سَمِيعًا بَصِيرًا ‏"‏‏.‏ ثُمَّ أَتَى عَلَىَّ وَأَنَا أَقُولُ فِي نَفْسِي لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ‏.‏ فَقَالَ ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ قُلْ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ فَإِنَّهَا‏.‏ كَنْزٌ مِنْ كُنُوزِ الْجَنَّةِ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ أَلاَ أَدُلُّكَ عَلَى كَلِمَةٍ هِيَ كَنْزٌ مِنْ كُنُوزِ الْجَنَّةِ، لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏‏.‏\hadithno{6384}\hadithtrans{Narrated Abu Musa:We were in the company of the Prophet (ﷺ) on a journey, and whenever we ascended a high place, we used to say Takbir (in a loud voice). The Prophet (ﷺ) said, "O people! Be kind to yourselves, for you are not calling upon a deaf or an absent one, but You are calling an All-Hearer, and an All-Seer." Then he came to me as I was reciting silently, "La haul a wala quwwata illa bil-lah." He said, "O `Abdullah bin Qais! Say: La haul a walaquwata illa bil-lah, for it is one of the treasures of Paradise." Or he said, "Shall I tell you a word which is one of the treasures of Paradise? It is: La haul a wala quwwata illa bil-lah}}
\hadithdefcmd{bukhari}{6385}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَفَلَ مِنْ غَزْوٍ أَوْ حَجٍّ أَوْ عُمْرَةٍ يُكَبِّرُ عَلَى كُلِّ شَرَفٍ مِنَ الأَرْضِ ثَلاَثَ تَكْبِيرَاتٍ، ثُمَّ يَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ، وَهْوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ، آيِبُونَ تَائِبُونَ، عَابِدُونَ لِرَبِّنَا، حَامِدُونَ، صَدَقَ اللَّهُ وَعْدَهُ، وَنَصَرَ عَبْدَهُ، وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏‏.‏\hadithno{6385}\hadithtrans{Narrated Ibn `Umar:Whenever Allah's Messenger (ﷺ) returned from a Ghazwa or Hajj or `Umra, he used to say, "Allahu Akbar," three times; whenever he went up a high place, he used to say, "La ilaha illal-lahu wahdahu la sharika lahu, lahu-l-mulk wa lahu-l-hamd, wa huwa'ala kulli Shai 'in qadir. Ayibuna ta'ibuna 'abiduna lirabbina hamidun. Sadaqa-l-lahu wa'dahu, wa nasara`Abdahu wa hazama-l-ahzaba wahdahu}}
\hadithdefcmd{bukhari}{6386}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ رَأَى النَّبِيُّ صلى الله عليه وسلم عَلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَثَرَ صُفْرَةٍ فَقَالَ ‏"‏ مَهْيَمْ ‏"‏‏.‏ أَوْ ‏"‏ مَهْ ‏"‏‏.‏ قَالَ تَزَوَّجْتُ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ‏.‏ فَقَالَ ‏"‏ بَارَكَ اللَّهُ لَكَ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{6386}\hadithtrans{Narrated Anas:The Prophet (ﷺ) seeing a yellow mark (of perfume) on the clothes of `Abdur-Rahman bin `Auf, said, "What about you?" `Abdur-Rahman replied, "I have married a woman with a Mahr of gold equal to a date-stone." The Prophet (ﷺ) said, "May Allah bestow His Blessing on you (in your marriage). Give a wedding banquet, (Walima) even with one sheep}}
\hadithdefcmd{bukhari}{6387}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرٍو، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ هَلَكَ أَبِي وَتَرَكَ سَبْعَ ـ أَوْ تِسْعَ ـ بَنَاتٍ، فَتَزَوَّجْتُ امْرَأَةً فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَزَوَّجْتَ يَا جَابِرُ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ بِكْرًا أَمْ ثَيِّبًا ‏"‏‏.‏ قُلْتُ ثَيِّبًا‏.‏ قَالَ ‏"‏ هَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ، أَوْ تُضَاحِكُهَا وَتُضَاحِكُكَ ‏"‏‏.‏ قُلْتُ هَلَكَ أَبِي فَتَرَكَ سَبْعَ ـ أَوْ تِسْعَ ـ بَنَاتٍ، فَكَرِهْتُ أَنْ أَجِيئَهُنَّ بِمِثْلِهِنَّ، فَتَزَوَّجْتُ امْرَأَةً تَقُومُ عَلَيْهِنَّ‏.‏ قَالَ ‏"‏ فَبَارَكَ اللَّهُ عَلَيْكَ ‏"‏‏.‏ لَمْ يَقُلِ ابْنُ عُيَيْنَةَ وَمُحَمَّدُ بْنُ مُسْلِمٍ عَنْ عَمْرٍو ‏"‏ بَارَكَ اللَّهُ عَلَيْكَ ‏"‏‏.‏\hadithno{6387}\hadithtrans{Narrated Jabir:My father died and left behind seven or nine daughters, and I married a woman. The Prophet (ﷺ) said, "Did you get married, O Jabir?" I replied, "Yes." He asked, "Is she a virgin or a matron?" I replied, "She is a matron." He said, "Why didn't you marry a virgin girl so that you might play with her and she with you (or, you might make her laugh and she make you laugh)?" I said, "My father died, leaving seven or nine girls (orphans) and I did not like to bring a young girl like them, so I married a woman who can look after them." He said, "May Allah bestow His Blessing on you}}
\hadithdefcmd{bukhari}{6388}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ أَحَدَهُمْ إِذَا أَرَادَ أَنْ يَأْتِيَ أَهْلَهُ قَالَ بِاسْمِ اللَّهِ، اللَّهُمَّ جَنِّبْنَا الشَّيْطَانَ، وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنَا، فَإِنَّهُ إِنْ يُقَدَّرْ بَيْنَهُمَا وَلَدٌ فِي ذَلِكَ، لَمْ يَضُرَّهُ شَيْطَانٌ أَبَدًا ‏"‏‏.‏\hadithno{6388}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "If anyone of you, when intending to have a sexual intercourse with his wife, says: 'Bismillah, Allahumma jannibna-sh-shaitan, wa jannibi-sh-shaitan ma razaqtana,' and if the couple are destined to have a child (out of that very sexual relation), then Satan will never be able to harm that child}}
\hadithdefcmd{bukhari}{6389}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ كَانَ أَكْثَرُ دُعَاءِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ رَبَّنَا آتِنَا فِي الدُّنْيَا حَسَنَةً، وَفِي الآخِرَةِ حَسَنَةً، وَقِنَا عَذَابَ النَّارِ ‏"‏‏.‏\hadithno{6389}\hadithtrans{Narrated Anas:The most frequent invocation of The Prophet (ﷺ) was: "O Allah! Give to us in the world that which is good and in the Hereafter that which is good, and save us from the torment of the Fire}}
\hadithdefcmd{bukhari}{6390}{حَدَّثَنَا فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُصْعَبِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعَلِّمُنَا هَؤُلاَءِ الْكَلِمَاتِ كَمَا تُعَلَّمُ الْكِتَابَةُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ، وَأَعُوذُ بِكَ مِنَ الْجُبْنِ، وَأَعُوذُ بِكَ مِنْ أَنْ نُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا، وَعَذَابِ الْقَبْرِ ‏"‏‏.‏\hadithno{6390}\hadithtrans{Narrated Sa`d bin Abi Waqqas:The Prophet (ﷺ) used to teach us these words as he used to teach us the Book (Qur'an): "O Allah! seek refuge with You from miserliness, and seek refuge with You from cowardice, and seek refuge with You from being brought back to (senile) geriatric old age, and seek refuge with You from the affliction of the world and from the punishment in the Hereafter}}
\hadithdefcmd{bukhari}{6391}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُنْذِرٍ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طُبَّ حَتَّى إِنَّهُ لَيُخَيَّلُ إِلَيْهِ قَدْ صَنَعَ الشَّىْءَ وَمَا صَنَعَهُ، وَإِنَّهُ دَعَا رَبَّهُ ثُمَّ قَالَ ‏"‏ أَشَعَرْتِ أَنَّ اللَّهَ قَدْ أَفْتَانِي فِيمَا اسْتَفْتَيْتُهُ فِيهِ ‏"‏‏.‏ فَقَالَتْ عَائِشَةُ فَمَا ذَاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ جَاءَنِي رَجُلاَنِ فَجَلَسَ أَحَدُهُمَا عِنْدَ رَأْسِي، وَالآخَرُ عِنْدَ رِجْلَىَّ فَقَالَ أَحَدُهُمَا لِصَاحِبِهِ مَا وَجَعُ الرَّجُلِ قَالَ مَطْبُوبٌ‏.‏ قَالَ مَنْ طَبَّهُ قَالَ لَبِيدُ بْنُ الأَعْصَمِ‏.‏ قَالَ فِيمَا ذَا قَالَ فِي مُشْطٍ وَمُشَاطَةٍ وَجُفِّ طَلْعَةٍ‏.‏ قَالَ فَأَيْنَ هُوَ قَالَ فِي ذَرْوَانَ، وَذَرْوَانُ بِئْرٌ فِي بَنِي زُرَيْقٍ ‏"‏‏.‏ قَالَتْ فَأَتَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ رَجَعَ إِلَى عَائِشَةَ فَقَالَ ‏"‏ وَاللَّهِ لَكَأَنَّ مَاءَهَا نُقَاعَةُ الْحِنَّاءِ، وَلَكَأَنَّ نَخْلَهَا رُءُوسُ الشَّيَاطِينِ ‏"‏‏.‏ قَالَتْ فَأَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهَا عَنِ الْبِئْرِ، فَقُلْتُ يَا رَسُولَ اللَّهِ فَهَلاَّ أَخْرَجْتَهُ قَالَ ‏"‏ أَمَّا أَنَا فَقَدْ شَفَانِي اللَّهُ، وَكَرِهْتُ أَنْ أُثِيرَ عَلَى النَّاسِ شَرًّا ‏"‏‏.‏ زَادَ عِيسَى بْنُ يُونُسَ وَاللَّيْثُ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ عَائِشَةَ قَالَتْ سُحِرَ النَّبِيُّ صلى الله عليه وسلم فَدَعَا وَدَعَا وَسَاقَ الْحَدِيثَ\hadithno{6391}\hadithtrans{Narrated `Aisha:that Allah's Messenger (ﷺ) was affected by magic, so much that he used to think that he had done something which in fact, he did not do, and he invoked his Lord (for a remedy). Then (one day) he said, "O `Aisha!) Do you know that Allah has advised me as to the problem I consulted Him about?" `Aisha said, "O Allah's Messenger (ﷺ)! What's that?" He said, "Two men came to me and one of them sat at my head and the other at my feet, and one of them asked his companion, 'What is wrong with this man?' The latter replied, 'He is under the effect of magic.' The former asked, 'Who has worked magic on him?' The latter replied, 'Labid bin Al-A'sam.' The former asked, 'With what did he work the magic?' The latter replied, 'With a comb and the hair, which are stuck to the comb, and the skin of pollen of a date-palm tree.' The former asked, 'Where is that?' The latter replied, 'It is in Dharwan.' Dharwan was a well in the dwelling place of the (tribe of) Bani Zuraiq. Allah's Messenger (ﷺ) went to that well and returned to `Aisha, saying, 'By Allah, the water (of the well) was as red as the infusion of Hinna, (1) and the date-palm trees look like the heads of devils.' `Aisha added, Allah's Messenger (ﷺ) came to me and informed me about the well. I asked the Prophet, 'O Allah's Messenger (ﷺ), why didn't you take out the skin of pollen?' He said, 'As for me, Allah has cured me and I hated to draw the attention of the people to such evil (which they might learn and harm others with).' " Narrated Hisham's father: `Aisha said, "Allah's Messenger (ﷺ) was bewitched, so he invoked Allah repeatedly requesting Him to cure him from that magic)." Hisham then narrated the above narration. (See Hadith No. 658, Vol)}}
\hadithdefcmd{bukhari}{6392}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي خَالِدٍ، قَالَ سَمِعْتُ ابْنَ أَبِي أَوْفَى ـ رضى الله عنهما ـ قَالَ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الأَحْزَابِ فَقَالَ ‏ "‏ اللَّهُمَّ مُنْزِلَ الْكِتَابِ، سَرِيعَ الْحِسَابِ، اهْزِمِ الأَحْزَابَ، اهْزِمْهُمْ وَزَلْزِلْهُمْ ‏"‏‏.‏\hadithno{6392}\hadithtrans{Narrated Ibn Abi `Aufa:Allah's Messenger (ﷺ) asked for Allah's wrath upon the Ahzab (confederates), saying, "O Allah, the Revealer of the Holy Book, and the One swift at reckoning! Defeat the confederates; Defeat them and shake them}}
\hadithdefcmd{bukhari}{6393}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏‏.‏ فِي الرَّكْعَةِ الآخِرَةِ مِنْ صَلاَةِ الْعِشَاءِ قَنَتَ ‏"‏ اللَّهُمَّ أَنْجِ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ، اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ، اللَّهُمَّ أَنْجِ سَلَمَةَ بْنَ هِشَامٍ، اللَّهُمَّ أَنْجِ الْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ، اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ، اللَّهُمَّ اجْعَلْهَا سِنِينَ كَسِنِي يُوسُفَ ‏"‏‏.‏\hadithno{6393}\hadithtrans{Narrated Abu Huraira:When the Prophet (ﷺ) said, "Sami' al-lahu liman hamidah (Allah heard him who sent his praises to Him)" in the last rak`a of the `Isha' prayer, he used to invoke Allah, saying, "O Allah! Save `Aiyash bin Abi Rabi`a; O Allah! Save Al-Walid bin Al-Walid; O Allah! Save the weak people among the believers; O Allah! Be hard on the Tribe of Mudar; O Allah! Inflict years of drought upon them like the years (of drought) of the Prophet (ﷺ) Joseph}}
\hadithdefcmd{bukhari}{6394}{حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَاصِمٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم سَرِيَّةً يُقَالُ لَهُمُ الْقُرَّاءُ فَأُصِيبُوا، فَمَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَجَدَ عَلَى شَىْءٍ مَا وَجَدَ عَلَيْهِمْ، فَقَنَتَ شَهْرًا فِي صَلاَةِ الْفَجْرِ وَيَقُولُ ‏ "‏ إِنَّ عُصَيَّةَ عَصَوُا اللَّهَ وَرَسُولَهُ ‏"‏‏.‏\hadithno{6394}\hadithtrans{Narrated Anas:The Prophet (ﷺ) sent a Sariya (an army detachment) consisting of men called Al-Qurra', and all of them were martyred. I had never seen the Prophet (ﷺ) so sad over anything as he was over them. So he said Qunut (invocation in the prayer) for one month in the Fajr prayer, invoking for Allah's wrath upon the tribe of 'Usaiya, and he used to say, "The people of 'Usaiya have disobeyed Allah and His Apostle}}
\hadithdefcmd{bukhari}{6395}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ الْيَهُودُ يُسَلِّمُونَ عَلَى النَّبِيِّ صلى الله عليه وسلم يَقُولُونَ السَّامُ عَلَيْكَ‏.‏ فَفَطِنَتْ عَائِشَةُ إِلَى قَوْلِهِمْ فَقَالَتْ عَلَيْكُمُ السَّامُ وَاللَّعْنَةُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَهْلاً يَا عَائِشَةُ، إِنَّ اللَّهَ يُحِبُّ الرِّفْقَ فِي الأَمْرِ كُلِّهِ ‏"‏‏.‏ فَقَالَتْ يَا نَبِيَّ اللَّهِ أَوَلَمْ تَسْمَعْ مَا يَقُولُونَ قَالَ ‏"‏ أَوَلَمْ تَسْمَعِي أَنِّي أَرُدُّ ذَلِكَ عَلَيْهِمْ فَأَقُولُ وَعَلَيْكُمْ ‏"‏‏.‏\hadithno{6395}\hadithtrans{Narrated `Aisha:The Jews used to greet the Prophet (ﷺ) by saying, "As-Samu 'Alaika (i.e., death be upon you), so I understood what they said, and I said to them, "As-Samu 'alaikum wal-la'na (i.e. Death and Allah's Curse be upon you)." The Prophet (ﷺ) said, "Be gentle and calm, O `Aisha, as Allah likes gentleness in all affairs." I said, "O Allah's Prophet! Didn't you hear what they said?" He said, "Didn't you hear me answering them back by saying, 'Alaikum (i.e., the same be upon you)?}}
\hadithdefcmd{bukhari}{6396}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، حَدَّثَنَا عَبِيدَةُ، حَدَّثَنَا عَلِيُّ بْنُ أَبِي طَالِبٍ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم يَوْمَ الْخَنْدَقِ، فَقَالَ ‏ "‏ مَلأَ اللَّهُ قُبُورَهُمْ وَبُيُوتَهُمْ نَارًا، كَمَا شَغَلُونَا عَنْ صَلاَةِ الْوُسْطَى حَتَّى غَابَتِ الشَّمْسُ ‏"‏‏.‏ وَهْىَ صَلاَةُ الْعَصْرِ‏.‏\hadithno{6396}\hadithtrans{Narrated `Ali bin Abi Talib:We were in the company of the Prophet (ﷺ) on the day (of the battle) of Al-Khandaq (the Trench). The Prophet said, "May Allah fill their (the infidels') graves and houses with fire, as they have kept us so busy that we could not offer the middle prayer till the sun had set; and that prayer was the `Asr prayer}}
\hadithdefcmd{bukhari}{6397}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَدِمَ الطُّفَيْلُ بْنُ عَمْرٍو عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ دَوْسًا قَدْ عَصَتْ وَأَبَتْ، فَادْعُ اللَّهَ عَلَيْهَا‏.‏ فَظَنَّ النَّاسُ أَنَّهُ يَدْعُو عَلَيْهِمْ، فَقَالَ ‏ "‏ اللَّهُمَّ اهْدِ دَوْسًا وَأْتِ بِهِمْ ‏"‏‏.‏\hadithno{6397}\hadithtrans{Narrated Abu Huraira:at-Tufail bin `Amr came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! The tribe of Daus has disobeyed (Allah and His Apostle) and refused (to embrace Islam), therefore, invoke Allah's wrath for them." The people thought that the Prophet (ﷺ) would invoke Allah's wrath for them, but he said, "O Allah! Guide the tribe Of Daus and let them come to us}}
\hadithdefcmd{bukhari}{6398}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْمَلِكَ بْنُ صَبَّاحٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ ابْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَدْعُو بِهَذَا الدُّعَاءِ ‏ "‏ رَبِّ اغْفِرْ لِي خَطِيئَتِي وَجَهْلِي وَإِسْرَافِي فِي أَمْرِي كُلِّهِ، وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي، اللَّهُمَّ اغْفِرْ لِي خَطَايَاىَ وَعَمْدِي وَجَهْلِي وَهَزْلِي، وَكُلُّ ذَلِكَ عِنْدِي، اللَّهُمَّ اغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ، أَنْتَ الْمُقَدِّمُ، وَأَنْتَ الْمُؤَخِّرُ، وَأَنْتَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏‏.‏ وَقَالَ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ وَحَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏ بِنَحْوِهِ.‏\hadithno{6398}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) used to invoke Allah with the following invocation: 'Rabbi-ghfir-li Khati 'ati wa jahli wa israfi fi `Amri kullihi, wa ma anta a'lamu bihi minni. Allahumma ighfirli khatayaya wa 'amdi, wa jahli wa jiddi, wa kullu dhalika'indi. Allahumma ighrifli ma qaddamtu wa ma akhartu wa ma asrartu wa ma a'lantu. Anta-l-muqaddimu wa anta-l-mu'akh-khiru, wa anta 'ala kulli shai'in qadir}}
\hadithdefcmd{bukhari}{6399}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا إِسْرَائِيلُ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مُوسَى، وَأَبِي، بُرْدَةَ ـ أَحْسِبُهُ ـ عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَدْعُو ‏ "‏ اللَّهُمَّ اغْفِرْ لِي خَطِيئَتِي وَجَهْلِي وَإِسْرَافِي فِي أَمْرِي، وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي، اللَّهُمَّ اغْفِرْ لِي هَزْلِي وَجِدِّي وَخَطَاىَ وَعَمْدِي، وَكُلُّ ذَلِكَ عِنْدِي ‏"‏‏.‏\hadithno{6399}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) used to invoke Allah, saying, "Allahumma ighfirli khati'ati wa jahli wa israfi fi `Amri, wa ma anta a-'lamu bihi minni. Allahumma ighfirli hazali wa jiddi wa khata'i wa amdi, wa kullu dhalika 'indi}}
\hadithdefcmd{bukhari}{6400}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ فِي الْجُمُعَةِ سَاعَةٌ لاَ يُوَافِقُهَا مُسْلِمٌ وَهْوَ قَائِمٌ يُصَلِّي يَسْأَلُ خَيْرًا إِلاَّ أَعْطَاهُ ‏"‏‏.‏ وَقَالَ بِيَدِهِ قُلْنَا يُقَلِّلُهَا يُزَهِّدُهَا‏.‏\hadithno{6400}\hadithtrans{Narrated Abu Huraira:Abu-l-Qasim (the Prophet) said, "On Friday there is a particular time. If a Muslim happens to be praying and invoking Allah for something good during that time, Allah will surely fulfill his request." The Prophet (ﷺ) pointed out with his hand. We thought that he wanted to illustrate how short that time was}}
\hadithdefcmd{bukhari}{6401}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ الْيَهُودَ، أَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا السَّامُ عَلَيْكَ‏.‏ قَالَ ‏"‏ وَعَلَيْكُمْ ‏"‏‏.‏ فَقَالَتْ عَائِشَةُ السَّامُ عَلَيْكُمْ، وَلَعَنَكُمُ اللَّهُ وَغَضِبَ عَلَيْكُمْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَهْلاً يَا عَائِشَةُ، عَلَيْكِ بِالرِّفْقِ، وَإِيَّاكِ وَالْعُنْفَ أَوِ الْفُحْشَ ‏"‏‏.‏ قَالَتْ أَوَلَمْ تَسْمَعْ مَا قَالُوا قَالَ ‏"‏ أَوَلَمْ تَسْمَعِي مَا قُلْتُ رَدَدْتُ عَلَيْهِمْ، فَيُسْتَجَابُ لِي فِيهِمْ، وَلاَ يُسْتَجَابُ لَهُمْ فِيَّ ‏"‏‏.‏\hadithno{6401}\hadithtrans{Narrated Ibn Abi Mulaika:`Aisha said, "The Jews came to the Prophet (ﷺ) and said to him, "As-Samu 'Alaika (i.e., Death be upon you)." He replied, 'The same on you.' " `Aisha said to them, "Death be upon you, and may Allah curse you and shower His wrath upon you!" Allah's Messenger (ﷺ) said, "Be gentle and calm, O `Aisha! Be gentle and beware of being harsh and of saying evil things." She said, "Didn't you hear what they said?" He said, "Didn't you hear what I replied (to them)? have returned their statement to them, and my invocation against them will be accepted but theirs against me will not be accepted}}
\hadithdefcmd{bukhari}{6402}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ حَدَّثَنَاهُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَمَّنَ الْقَارِئُ فَأَمِّنُوا، فَإِنَّ الْمَلاَئِكَةَ تُؤَمِّنُ، فَمَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{6402}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When the Imam says 'Amin', then you should all say 'Amin', for the angels say 'Amin' at that time, and he whose 'Amin' coincides with the 'Amin' of the angels, all his past sins will be forgiven}}
\hadithdefcmd{bukhari}{6403}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ، وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ، وَهْوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ‏.‏ فِي يَوْمٍ مِائَةَ مَرَّةٍ، كَانَتْ لَهُ عَدْلَ عَشْرِ رِقَابٍ، وَكُتِبَ لَهُ مِائَةُ حَسَنَةٍ، وَمُحِيَتْ عَنْهُ مِائَةُ سَيِّئَةٍ، وَكَانَتْ لَهُ حِرْزًا مِنَ الشَّيْطَانِ يَوْمَهُ ذَلِكَ، حَتَّى يُمْسِيَ، وَلَمْ يَأْتِ أَحَدٌ بِأَفْضَلَ مِمَّا جَاءَ بِهِ إِلاَّ رَجُلٌ عَمِلَ أَكْثَرَ مِنْهُ ‏"‏‏.‏\hadithno{6403}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said," Whoever says: "La ilaha illal-lah wahdahu la sharika lahu, lahu-l-mulk wa lahul- hamd wa huwa 'ala kulli shai'in qadir," one hundred times will get the same reward as given for manumitting ten slaves; and one hundred good deeds will be written in his accounts, and one hundred sins will be deducted from his accounts, and it (his saying) will be a shield for him from Satan on that day till night, and nobody will be able to do a better deed except the one who does more than he}}
\hadithdefcmd{bukhari}{6404}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا عُمَرُ بْنُ أَبِي زَائِدَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ مَنْ قَالَ عَشْرًا كَانَ كَمَنْ أَعْتَقَ رَقَبَةً مِنْ وَلَدِ إِسْمَاعِيلَ‏.‏ قَالَ عُمَرُ بْنُ أَبِي زَائِدَةَ وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي السَّفَرِ عَنِ الشَّعْبِيِّ عَنْ رَبِيعِ بْنِ خُثَيْمٍ مِثْلَهُ‏.‏ فَقُلْتُ لِلرَّبِيعِ مِمَّنْ سَمِعْتَهُ فَقَالَ مِنْ عَمْرِو بْنِ مَيْمُونٍ‏.‏ فَأَتَيْتُ عَمْرَو بْنَ مَيْمُونٍ فَقُلْتُ مِمَّنْ سَمِعْتَهُ فَقَالَ مِنِ ابْنِ أَبِي لَيْلَى‏.‏ فَأَتَيْتُ ابْنَ أَبِي لَيْلَى فَقُلْتُ مِمَّنْ سَمِعْتَهُ فَقَالَ مِنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ يُحَدِّثُهُ عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَالَ إِبْرَاهِيمُ بْنُ يُوسُفَ عَنْ أَبِيهِ عَنْ أَبِي إِسْحَاقَ حَدَّثَنِي عَمْرُو بْنُ مَيْمُونٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى عَنْ أَبِي أَيُّوبَ قَوْلَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ مُوسَى حَدَّثَنَا وُهَيْبٌ، عَنْ دَاوُدَ، عَنْ عَامِرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ إِسْمَاعِيلُ عَنِ الشَّعْبِيِّ عَنِ الرَّبِيعِ قَوْلَهُ‏.‏ وَقَالَ آدَمُ حَدَّثَنَا شُعْبَةُ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مَيْسَرَةَ سَمِعْتُ هِلاَلَ بْنَ يَسَافٍ عَنِ الرَّبِيعِ بْنِ خُثَيْمٍ وَعَمْرِو بْنِ مَيْمُونٍ عَنِ ابْنِ مَسْعُودٍ قَوْلَهُ‏.‏ وَقَالَ الأَعْمَشُ وَحُصَيْنٌ عَنْ هِلاَلٍ عَنِ الرَّبِيعِ عَنْ عَبْدِ اللَّهِ قَوْلَهُ‏.‏ وَرَوَاهُ أَبُو مُحَمَّدٍ الْحَضْرَمِيُّ عَنْ أَبِي أَيُّوبَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏ كَانَ كَمَنْ أَعْتَقَ رَقَبَةً مِنْ وَلَدِ إِسْمَاعِيلِ قَالَ أَبُو عَبْد اللَّهِ وَالصَّحِيحُ قَوْلُ عَبْدِ الْمَلِكِ بْنِ عَمْرٍو.‏\hadithno{6404}\hadithtrans{Narrated `Amr bin Maimun:Whoever recites it (i.e., the invocation in the above Hadith (412) ten times will be as if he manumitted one of Ishmael's descendants. Abu Aiyub narrated the same Hadith from the Prophet (ﷺ) saying, "(Whoever recites it ten times) will be as if he had manumitted one of Ishmael's descendants}}
\hadithdefcmd{bukhari}{6405}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ‏.‏ فِي يَوْمٍ مِائَةَ مَرَّةٍ حُطَّتْ خَطَايَاهُ، وَإِنْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏‏.‏\hadithno{6405}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever says, 'Subhan Allah wa bihamdihi,' one hundred times a day, will be forgiven all his sins even if they were as much as the foam of the sea}}
\hadithdefcmd{bukhari}{6406}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَلِمَتَانِ خَفِيفَتَانِ عَلَى اللِّسَانِ، ثَقِيلَتَانِ فِي الْمِيزَانِ، حَبِيبَتَانِ إِلَى الرَّحْمَنِ، سُبْحَانَ اللَّهِ الْعَظِيمِ، سُبْحَانَ اللَّهِ وَبِحَمْدِهِ ‏"‏‏.‏\hadithno{6406}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There are two expressions which are very easy for the tongue to say, but they are very heavy in the balance and are very dear to The Beneficent (Allah), and they are, 'Subhan Allah Al- `Azim and 'Subhan Allah wa bihamdihi}}
\hadithdefcmd{bukhari}{6407}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَثَلُ الَّذِي يَذْكُرُ رَبَّهُ وَالَّذِي لاَ يَذْكُرُ مَثَلُ الْحَىِّ وَالْمَيِّتِ ‏"‏‏.‏\hadithno{6407}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "The example of the one who celebrates the Praises of his Lord (Allah) in comparison to the one who does not celebrate the Praises of his Lord, is that of a living creature compared to a dead one}}
\hadithdefcmd{bukhari}{6408}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِلَّهِ مَلاَئِكَةً يَطُوفُونَ فِي الطُّرُقِ، يَلْتَمِسُونَ أَهْلَ الذِّكْرِ، فَإِذَا وَجَدُوا قَوْمًا يَذْكُرُونَ اللَّهَ تَنَادَوْا هَلُمُّوا إِلَى حَاجَتِكُمْ‏.‏ قَالَ فَيَحُفُّونَهُمْ بِأَجْنِحَتِهِمْ إِلَى السَّمَاءِ الدُّنْيَا‏.‏ قَالَ فَيَسْأَلُهُمْ رَبُّهُمْ وَهْوَ أَعْلَمُ مِنْهُمْ مَا يَقُولُ عِبَادِي قَالُوا يَقُولُونَ يُسَبِّحُونَكَ، وَيُكَبِّرُونَكَ، وَيَحْمَدُونَكَ وَيُمَجِّدُونَكَ‏.‏ قَالَ فَيَقُولُ هَلْ رَأَوْنِي قَالَ فَيَقُولُونَ لاَ وَاللَّهِ مَا رَأَوْكَ‏.‏ قَالَ فَيَقُولُ وَكَيْفَ لَوْ رَأَوْنِي قَالَ يَقُولُونَ لَوْ رَأَوْكَ كَانُوا أَشَدَّ لَكَ عِبَادَةً، وَأَشَدَّ لَكَ تَمْجِيدًا، وَأَكْثَرَ لَكَ تَسْبِيحًا‏.‏ قَالَ يَقُولُ فَمَا يَسْأَلُونِي قَالَ يَسْأَلُونَكَ الْجَنَّةَ‏.‏ قَالَ يَقُولُ وَهَلْ رَأَوْهَا قَالَ يَقُولُونَ لاَ وَاللَّهِ يَا رَبِّ مَا رَأَوْهَا‏.‏ قَالَ يَقُولُ فَكَيْفَ لَوْ أَنَّهُمْ رَأَوْهَا قَالَ يَقُولُونَ لَوْ أَنَّهُمْ رَأَوْهَا كَانُوا أَشَدَّ عَلَيْهَا حِرْصًا، وَأَشَدَّ لَهَا طَلَبًا، وَأَعْظَمَ فِيهَا رَغْبَةً‏.‏ قَالَ فَمِمَّ يَتَعَوَّذُونَ قَالَ يَقُولُونَ مِنَ النَّارِ‏.‏ قَالَ يَقُولُ وَهَلْ رَأَوْهَا قَالَ يَقُولُونَ لاَ وَاللَّهِ مَا رَأَوْهَا‏.‏ قَالَ يَقُولُ فَكَيْفَ لَوْ رَأَوْهَا قَالَ يَقُولُونَ لَوْ رَأَوْهَا كَانُوا أَشَدَّ مِنْهَا فِرَارًا، وَأَشَدَّ لَهَا مَخَافَةً‏.‏ قَالَ فَيَقُولُ فَأُشْهِدُكُمْ أَنِّي قَدْ غَفَرْتُ لَهُمْ‏.‏ قَالَ يَقُولُ مَلَكٌ مِنَ الْمَلاَئِكَةِ فِيهِمْ فُلاَنٌ لَيْسَ مِنْهُمْ إِنَّمَا جَاءَ لِحَاجَةٍ‏.‏ قَالَ هُمُ الْجُلَسَاءُ لاَ يَشْقَى بِهِمْ جَلِيسُهُمْ ‏"‏‏.‏ رَوَاهُ شُعْبَةُ عَنِ الأَعْمَشِ وَلَمْ يَرْفَعْهُ‏.‏ وَرَوَاهُ سُهَيْلٌ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6408}\hadithtrans{Narrated Abu Huraira:Allah's Apostle said, "Allah has some angels who look for those who celebrate the Praises of Allah on the roads and paths. And when they find some people celebrating the Praises of Allah, they call each other, saying, "Come to the object of your pursuit.' " He added, "Then the angels encircle them with their wings up to the sky of the world." He added. "(after those people celebrated the Praises of Allah, and the angels go back), their Lord, asks them (those angels)----though He knows better than them----'What do My slaves say?' The angels reply, 'They say: Subhan Allah, Allahu Akbar, and Alham-du-li l-lah, Allah then says 'Did they see Me?' The angels reply, 'No! By Allah, they didn't see You.' Allah says, How it would have been if they saw Me?' The angels reply, 'If they saw You, they would worship You more devoutly and celebrate Your Glory more deeply, and declare Your freedom from any resemblance to anything more often.' Allah says (to the angels), 'What do they ask Me for?' The angels reply, 'They ask You for Paradise.' Allah says (to the angels), 'Did they see it?' The angels say, 'No! By Allah, O Lord! They did not see it.' Allah says, How it would have been if they saw it?' The angels say, 'If they saw it, they would have greater covetousness for it and would seek It with greater zeal and would have greater desire for it.' Allah says, 'From what do they seek refuge?' The angels reply, 'They seek refuge from the (Hell) Fire.' Allah says, 'Did they see it?' The angels say, 'No By Allah, O Lord! They did not see it.' Allah says, How it would have been if they saw it?' The angels say, 'If they saw it they would flee from it with the extreme fleeing and would have extreme fear from it.' Then Allah says, 'I make you witnesses that I have forgiven them."' Allah's Messenger (ﷺ) added, "One of the angels would say, 'There was so-and-so amongst them, and he was not one of them, but he had just come for some need.' Allah would say, 'These are those people whose companions will not be reduced to misery}}
\hadithdefcmd{bukhari}{6409}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ أَخَذَ النَّبِيُّ صلى الله عليه وسلم فِي عَقَبَةٍ ـ أَوْ قَالَ فِي ثَنِيَّةٍ، قَالَ ـ فَلَمَّا عَلاَ عَلَيْهَا رَجُلٌ نَادَى فَرَفَعَ صَوْتَهُ لاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ‏.‏ قَالَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى بَغْلَتِهِ قَالَ ‏"‏ فَإِنَّكُمْ لاَ تَدْعُونَ أَصَمَّ وَلاَ غَائِبًا ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ يَا أَبَا مُوسَى ـ أَوْ يَا عَبْدَ اللَّهِ أَلاَ أَدُلُّكَ عَلَى كَلِمَةٍ مِنْ كَنْزِ الْجَنَّةِ ‏"‏‏.‏ قُلْتُ بَلَى‏.‏ قَالَ ‏"‏ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏‏.‏\hadithno{6409}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) started ascending a high place or hill. A man (amongst his companions) ascended it and shouted in a loud voice, "La ilaha illal-lahu wallahu Akbar." (At that time) Allah's Messenger (ﷺ) was riding his mule. Allah's Messenger (ﷺ) said, "You are not calling upon a deaf or an absent one." and added, "O Abu Musa (or, O `Abdullah)! Shall I tell you a sentence from the treasure of Paradise?" I said, "Yes." He said, "La haul a wala quwwata illa billah}}
\hadithdefcmd{bukhari}{6410}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنْ أَبِي الزِّنَادِ عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، رِوَايَةً قَالَ ‏ "‏ لِلَّهِ تِسْعَةٌ وَتِسْعُونَ اسْمًا، مِائَةٌ إِلاَّ وَاحِدًا، لاَ يَحْفَظُهَا أَحَدٌ إِلاَّ دَخَلَ الْجَنَّةَ، وَهْوَ وَتْرٌ يُحِبُّ الْوَتْرَ ‏"‏‏.‏\hadithno{6410}\hadithtrans{Narrated Abu Huraira:Allah has ninety-nine Names, i.e., one hundred minus one, and whoever believes in their meanings and acts accordingly, will enter Paradise; and Allah is witr (one) and loves 'the witr' (i.e., odd numbers)}}
\hadithdefcmd{bukhari}{6411}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي شَقِيقٌ، قَالَ كُنَّا نَنْتَظِرُ عَبْدَ اللَّهِ إِذْ جَاءَ يَزِيدُ بْنُ مُعَاوِيَةَ فَقُلْنَا أَلاَ تَجْلِسُ قَالَ لاَ وَلَكِنْ أَدْخُلُ فَأُخْرِجُ إِلَيْكُمْ صَاحِبَكُمْ، وَإِلاَّ جِئْتُ أَنَا‏.‏ فَجَلَسْتُ فَخَرَجَ عَبْدُ اللَّهِ وَهْوَ آخِذٌ بِيَدِهِ فَقَامَ عَلَيْنَا فَقَالَ أَمَا إِنِّي أَخْبَرُ بِمَكَانِكُمْ، وَلَكِنَّهُ يَمْنَعُنِي مِنَ الْخُرُوجِ إِلَيْكُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَخَوَّلُنَا بِالْمَوْعِظَةِ فِي الأَيَّامِ، كَرَاهِيَةَ السَّآمَةِ عَلَيْنَا‏.‏\hadithno{6411}\hadithtrans{Narrated Shaqiq:While we were waiting for `Abdullah (bin Mas`ud). Yazid bin Muawiya came. I said (to him), "Will you sit down?" He said, "No, but I will go into the house (of Ibn Mas`ud) and let your companion (Ibn Mas`ud) come out to you; and if he should not (come out), I will come out and sit (with you)." Then `Abdullah came out, holding the hand of Yazid, addressed us, saying, "I know that you are assembled here, but the reason that prevents me from coming out to you, is that Allah's Messenger (ﷺ) used to preach to us at intervals during the days, lest we should become bored}}
